/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

import com.microej.fs.tests.methods.TestGetCanonicalFile;
import com.microej.fs.tests.methods.TestGetCanonicalPath_Windows;

/**
 * A class to gather all tests.
 * 
 * @author pgradot
 * 
 */
public class UtilTests {

	/**
	 * A entry point of the program.
	 * 
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		// System.out.println("--------------------------");
		// TestFileProperties.TestRelativePath();

		// TestGetAbsoluteFile.main(args);
		//
		// TestGetAbsolutePath.main(args);
		// TestGetAbsolutePath_Windows.main(args);

		// TestGetCanonicalPath.main(args);
		TestGetCanonicalPath_Windows.main(args);
		
		TestGetCanonicalFile.main(args);

	}

	public static boolean isRoot(File file) {
		if(file == null){
			return false;
		}
		
		String absolutePath = file.getAbsolutePath();
		File[] roots = File.listRoots();
		for (File root : roots) {
			if (root!=null && root.getAbsolutePath().equals(absolutePath)) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Returns true if the system is Windows, false otherwise.
	 */
	public static boolean onWindows(){
		return File.pathSeparator.equals("\\");
	}
	
	/**
	 * Returns true if the given file contains data, false otherwise.
	 * @throws IOException if the file does no exist.
	 */
	public static boolean fileContains(File f, String data) throws IOException{
		try(FileInputStream fis = new FileInputStream(f)){
			byte[] expected = data.getBytes();
			if(fis.available() != expected.length){
				return false;
			}
			
			byte[] content = new byte[expected.length];
			int nbRead = fis.read(content);
			if(nbRead != expected.length){
				return false;
			}
			
			for(int i=expected.length ; --i>=0 ;){
				if(content[i] != expected[i]){
					return false;
				}
			}
			
			return true;
		}
	}
	
	/**
	 * Returns true if the given file is empty, false otherwise.
	 * @throws IOException if the file does no exist.
	 */
	public static boolean fileIsEmpty(File f) throws IOException{
		try(FileInputStream fis = new FileInputStream(f)){
			return fis.available() == 0;
		}
	}
}
