/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.constructors;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for the constructor with one {@link String} as parameter, {@link File#File(String)}.
 *
 * @author pgradot
 *
 */
public class TestString {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestString.class);
		test001();
		test002();
		test003();

		CheckHelper.endCheck(TestString.class);
	}

	/**
	 * 'null' should raise a {@link NullPointerException}.
	 */
	public static void test001() {
		try {
			@SuppressWarnings("unused")
			File f = new File(null);
			CheckHelper.check(TestString.class, "'null' should raise a {@link NullPointerException}", false);
		} catch (NullPointerException e) {
			CheckHelper.check(TestString.class, "(Normal to get here)", true);
		}
	}

	/**
	 * An empty string should result in the empty abstract pathname.
	 */
	public static void test002() {
		File f = new File("");
		CheckHelper.check(TestString.class, "An empty string should result in the empty abstract pathname", f.getPath().equals(""));
	}

	/**
	 * A correct pathname string should create a correct abstract pathname.
	 */
	public static void test003() {
		File f = new File("A/B/C");
		String expectedPath = "A" + File.separator + "B" + File.separator + "C";
		CheckHelper.check(TestString.class, "", expectedPath.equals(f.getPath()));
		/*
		 * Java don't precisely specify how the abstract pathname is stored and there is no way to retrieve it directly. The closest way is getPath()
		 * but it returns a system-dependent pathname string.
		 *
		 * In our implementation, we know that we normalize paths in constructors, this is why "expectedPath" looks like this.
		 *
		 * For more advance tests on how constructors store they parameters, see the tests about path normalization.
		 */
	}

}
