/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.fields;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for 4 public static fields provided by {@link File} .
 *
 * @author pgradot
 *
 */
public class TestPublicFields {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestPublicFields.class);
		test001();
		test002();
		test003();
		test004();

		CheckHelper.endCheck(TestPublicFields.class);
	}

	/**
	 * 'separatorChar' should contain the first letter of the property 'file.separator'.
	 */
	public static void test001() {
		String property = System.getProperty("file.separator");
		char first = property.charAt(0);
		CheckHelper.check(TestPublicFields.class, "'separatorChar' should contain the first letter of the property 'file.separator'",
				first == File.separatorChar);
	}

	/**
	 * 'separator' should contain a single character, namely 'separatorChar'.
	 */
	public static void test002() {
		CheckHelper.check(TestPublicFields.class, "'separator' should contain a single char", File.separator.length() == 1);

		String expected = String.valueOf(File.separatorChar);
		CheckHelper.check(TestPublicFields.class, "'separator' should contain 'separatorChar'.", expected.equals(File.separator));
	}

	/**
	 * 'pathSeparatorChar' should contain the first letter of the property 'path.separator'.
	 */
	public static void test003() {
		String property = System.getProperty("path.separator");
		char first = property.charAt(0);
		CheckHelper.check(TestPublicFields.class, "'pathSeparatorChar' should contain the first letter of the property 'path.separator'",
				first == File.pathSeparatorChar);
	}

	/**
	 * 'pathSeparator' should contain a single character, namely 'pathSeparatorChar'.
	 */
	public static void test004() {
		CheckHelper.check(TestPublicFields.class, "'pathSeparator' should contain a single char", File.pathSeparator.length() == 1);

		String expected = String.valueOf(File.pathSeparatorChar);
		CheckHelper.check(TestPublicFields.class, "'pathSeparator' should contain 'pathSeparatorChar'.", expected.equals(File.pathSeparator));
	}

}
