/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.fields;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for 4 public static fields provided by {@link File} that are UNIX specific.
 *
 * @author pgradot
 *
 */
public class TestPublicFields_UNIX {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestPublicFields_UNIX ***");
		System.out.println(
				"This test can pass only if your platform has a UNIX file system. If your platform doesn't have a UNIX file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestPublicFields_UNIX.class);
		test001();
		test002();
		CheckHelper.endCheck(TestPublicFields_UNIX.class);
	}

	/**
	 * 'separatorChar' should contain '/' (one slash) on UNIX.
	 */
	public static void test001() {
		CheckHelper.check(TestPublicFields_Windows.class, "'separatorChar' should contain '/' (one slash) on UNIX", File.separatorChar == '/');
	}

	/**
	 * 'pathSeparatorChar' should contain ':' on UNIX.
	 */
	public static void test002() {
		CheckHelper.check(TestPublicFields_Windows.class, "'pathSeparatorChar' should contain ':' on UNIX", File.pathSeparatorChar == ':');
	}

}
