/*
 * Java
 *
 * Copyright 2019-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.helpers;

import java.io.File;

/**
 * Cleans the file system before performing tests
 */
public class FileSystemCleaner {
	private static final String userDirString = System.getProperty("user.dir");
	private static final String tmpDirString = System.getProperty("java.io.tmpdir");
	private static final boolean CLEAN_FS = Boolean.getBoolean("clean.fs.before.tests");

	public static void cleanFS() {
		if (CLEAN_FS) {
			if (userDirString != null) {
				File userDir = new File(userDirString);
				if (userDir.exists()) {
					deleteDirectoryContent(userDir);
				}
			}
			if (tmpDirString != null) {
				File tmpDir = new File(tmpDirString);
				if (tmpDir.exists()) {
					deleteDirectoryContent(tmpDir);
				}
			}
		}
	}

	private static void deleteDirectoryContent(File file) {
		File[] children = file.listFiles();
		for (File child : children) {
			delete(child);
		}
	}

	private static void delete(File file) {
		if (file.exists()) {
			if (file.isDirectory()) {
				deleteDirectoryContent(file);
			}
			file.delete();
		}
	}
}
