/*
 * Java
 *
 * Copyright 2016-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.integration;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestFile {

	public static void main(String[] args) throws InterruptedException{
		FileSystemCleaner.cleanFS();

		System.out.println("**************************");
		System.out.println("* FS : integration tests *");
		System.out.println("**************************");

		Class tS = TestFile.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestWriteBigFile", TestWriteBigFile());

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * TestWriteBigFile : Write and read data longer than immortal buffer length and test return value.
	 */
	public static boolean TestWriteBigFile() throws InterruptedException {
		System.out.println("**TestWriteBigFile");

		File file = new File(System.getProperty("user.dir"), "bigFile.txt");
		boolean res = false;

		try {
			file.createNewFile();
			FileOutputStream fos = new FileOutputStream(file, false);
			fos.write(System.getProperty("bigData").getBytes());
			fos.close();

			FileInputStream fis = new FileInputStream(file);
			byte[] data = new byte[System.getProperty("bigData").length()+1];
			fis.read(data, 0, System.getProperty("bigData").length()+1);

			String dataString = new String(data);
			if (dataString.startsWith(System.getProperty("bigData")+"\0")) {
				res = true;
			}

			fis.close();
			file.delete();

		} catch (IOException e) {
			e.printStackTrace();
			res = false;
		}
		return res;
	}
}
