/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Test {@link FileInputStream#close()} and {@link FileOutputStream#close()}.
 */
public class TestClose {

	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestClose.class);
		try {
			testFileInputStreamDoubleClose();
			testFileOutputStreamDoubleClose();
			testFileInputStreamActionsAfterClose();
			testFileOutputStreamActionsAfterClose();
		} catch (IOException e) {
			CheckHelper.check(TestClose.class, "IOException", false);
			e.printStackTrace();
		}

		CheckHelper.endCheck(TestClose.class);
	}

	/**
	 * Test closing twice a {@link FileInputStream}
	 */
	public static void testFileInputStreamDoubleClose() throws IOException{
		File file = File.createTempFile(TestClose.class.getSimpleName(), null);

		FileInputStream fis = new FileInputStream(file);
		fis.close();
		try{
			fis.close();
		}
		catch(IOException e){
		}

		boolean deleted = file.delete();

		CheckHelper.check(TestClose.class, "Deleted a file must work (FileInputStream)", deleted);
	}

	/**
	 * Test closing twice a {@link FileOutputStream}
	 */
	public static void testFileOutputStreamDoubleClose() throws IOException{
		File file = File.createTempFile(TestClose.class.getSimpleName(), null);

		FileOutputStream fos = new FileOutputStream(file);
		fos.close();
		try{
			fos.close();
		}
		catch(IOException e){
		}

		boolean deleted = file.delete();
		CheckHelper.check(TestClose.class, "Deleted a file must work (FileOutputStream)", deleted);
	}

	/**
	 * Tests that no action can be done on a {@link FileInputStream} after close
	 */
	public static void testFileInputStreamActionsAfterClose() throws IOException {
		File file = File.createTempFile(TestClose.class.getSimpleName(), null);

		FileInputStream fis = new FileInputStream(file);

		fis.close();

		try{
			fis.available();
			CheckHelper.check(TestClose.class, "available() must not work on a closed stream", false);
		}
		catch(IOException e){}
		try{
			fis.read();
			CheckHelper.check(TestClose.class, "read() must not work on a closed stream", false);
		}
		catch(IOException e){}
		try{
			fis.read(new byte[5]);
			CheckHelper.check(TestClose.class, "read(byte[]) must not work on a closed stream", false);
		}
		catch(IOException e){}
		try{
			fis.read(new byte[5], 0, 5);
			CheckHelper.check(TestClose.class, "read(byte[],int,int) must not work on a closed stream", false);
		}
		catch(IOException e){}
		try{
			fis.skip(10);
			CheckHelper.check(TestClose.class, "skip(int) must not work on a closed stream", false);
		}
		catch(IOException e){}

		file.delete();
	}


	/**
	 * Tests that no action can be done on a {@link FileOutputStream} after close
	 */
	public static void testFileOutputStreamActionsAfterClose() throws IOException {
		File file = File.createTempFile(TestClose.class.getSimpleName(), null);

		FileOutputStream fos = new FileOutputStream(file);

		fos.close();

		try{
			fos.flush();
			//flush is allowed on a closed stream
		}
		catch(IOException e){}
		try{
			fos.write(new byte[5]);
			CheckHelper.check(TestClose.class, "write(byte[]) must not work on a closed stream", false);
		}
		catch(IOException e){}
		try{
			fos.write(10);
			CheckHelper.check(TestClose.class, "write(int) must not work on a closed stream", false);
		}
		catch(IOException e){}
		try{
			fos.write(new byte[5], 0, 5);
			CheckHelper.check(TestClose.class, "write(byte[],int,int) must not work on a closed stream", false);
		}
		catch(IOException e){}

		file.delete();
	}
}
