/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#compareTo(File)}, made to be Windows specific.
 *
 * @author pgradot
 *
 */
public class TestCompareTo_caseInsensitive {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestCompareTo_caseInsensitive.class);
		if (System.getProperty("case.sensitivity").equals("caseInsensitive")) {
			test001();
			test002();
			test003();
		}

		CheckHelper.endCheck(TestCompareTo_caseInsensitive.class);
	}

	/**
	 * Two pathnames that differ only with alphabetic case should compare equal.
	 *
	 * Indeed, Windows is not case sensitive.
	 */
	public static void test001() {
		File reference = new File("FilE/reF");
		File compare = new File("file/rEf");

		CheckHelper.check(TestCompareTo_caseInsensitive.class, "Two pathnames than differ only with alphabetic case should compare equal",
				reference.compareTo(compare) == 0);
	}

	/**
	 * Alphabetic case should not affect comparison to a lower abstract pathname.
	 */
	public static void test002() {
		File reference = new File("file/B");
		File lower = new File("file/a");
		/*
		 * In ASCII table, 'B' (0x42) is lower than 'a' (0x61).
		 *
		 * Nevertheless, 'B' is greater than 'a' when case is ignored.
		 */
		CheckHelper.check(TestCompareTo_caseInsensitive.class, "Alphabetic case should not affect comparison to a lower abstract pathname",
				reference.compareTo(lower) > 0);
	}

	/**
	 * Alphabetic case should not affect comparison to a greater abstract pathname.
	 */
	public static void test003() {
		File reference = new File("file/b");
		File greater = new File("file/C");
		/*
		 * In ASCII table, 'b' (0x62) is greater than 'C' (0x43).
		 *
		 * Nevertheless, 'b' is lower than 'C' when case is ignored.
		 */
		CheckHelper.check(TestCompareTo_caseInsensitive.class, "Alphabetic case should not affect comparison to a greater abstract pathname",
				reference.compareTo(greater) < 0);
	}

}
