/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#compareTo(File)}, made to be UNIX specific.
 *
 * @author pgradot
 *
 */
public class TestCompareTo_caseSensitive {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestCompareTo_caseSensitive.class);
		if (System.getProperty("case.sensitivity").equals("caseSensitive")) {
			test001();
		}

		CheckHelper.endCheck(TestCompareTo_caseSensitive.class);
	}

	/**
	 * Two pathnames than differ only with alphabetic case should not compare equal.
	 *
	 * Indeed, UNIX is case sensitive.
	 */
	public static void test001() {
		File reference = new File("file/ref");
		File compare = new File("file/rEf");

		CheckHelper.check(TestCompareTo_caseSensitive.class, "Two pathnames than differ only with alphabetic case should not compare equal",
				reference.compareTo(compare) != 0);
	}

	/**
	 * Alphabetic case should affect comparison to a supposedly lower abstract pathname.
	 */
	public static void test002() {
		File reference = new File("file/B");
		File supposedlyLower = new File("file/a");
		/*
		 * In ASCII table, 'B' (0x42) is lower than 'a' (0x61).
		 */
		CheckHelper.check(TestCompareTo_caseSensitive.class, "Alphabetic case should affect comparison to a supposedly lower abstract pathname",
				reference.compareTo(supposedlyLower) < 0);
	}

	/**
	 * Alphabetic case should affect comparison to a supposedly greater abstract pathname.
	 */
	public static void test003() {
		File reference = new File("file/b");
		File supposedlyGreater = new File("file/C");
		/*
		 * In ASCII table, 'b' (0x62) is greater than 'C' (0x43).
		 */
		CheckHelper.check(TestCompareTo_caseSensitive.class, "Alphabetic case should affect comparison to a supposedly greater abstract pathname",
				reference.compareTo(supposedlyGreater) > 0);
	}

}
