/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Test {@link FileInputStream#close()} and {@link FileOutputStream#close()}.
 */
public class TestCreate {

	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestCreate.class);
		try {
			testCreateFileSimple();
			testCreateFileDouble();
		} catch (IOException e) {
			CheckHelper.check(TestCreate.class, "IOException", false);
			e.printStackTrace();
		}

		CheckHelper.endCheck(TestCreate.class);
	}

	/**
	 * Test just create file
	 */
	public static void testCreateFileSimple() throws IOException{
		File file = File.createTempFile(TestCreate.class.getSimpleName(), null);

		CheckHelper.check(TestCreate.class, "Create temp file must work", file.exists() == true);
		file.delete();
	}

	/**
	 * Test create file twice
	 */
	public static void testCreateFileDouble() throws IOException{
		File file = File.createTempFile(TestCreate.class.getSimpleName(), null);

		CheckHelper.check(TestCreate.class, "Creation file with already exiting name must return false", file.createNewFile() == false);
		file.delete();
	}
}
