/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Test {@link File#createTempFile(String, String)} and {@link File#createTempFile(String, String, File)}
 */
public class TestCreateTempFile {

	public static List<File> CreatedFiles = new ArrayList<>();

	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();

		CheckHelper.startCheck(TestCreateTempFile.class);
		try {
			checkTempFile("abc", null);
			checkTempFile("ab", null);
			checkTempFile("a", null);
			checkTempFile("", null);
			checkTempFile(null, null);
			checkTempFile("ab", "toubidou");
			checkTempFile("abcd", ".bidou");
			checkTempFile("abcd", ".toubidou");
			checkTempFile("abcd", "abc");
			checkTempFile("abcd", "abc");
			checkTempFile("abcd", "abc");
			checkTempFile("abcd", "abc");
		} catch (IOException e) {
			CheckHelper.check(TestCreateTempFile.class, "Exception", false);
			e.printStackTrace();
		}

		clean();
		CheckHelper.endCheck(TestCreateTempFile.class);
	}

	public  static void checkTempFile(String prefix, String suffix) throws IOException{
		checkTempFile(prefix, suffix, null, false);
	}

	public  static void checkTempFile(String prefix, String suffix, File parent) throws IOException{
		checkTempFile(prefix, suffix, parent, true);
	}

	private static void checkTempFile(String prefix, String suffix, File parent, boolean useParent) throws IOException{
		boolean correctPrefix = false;
		if(prefix!=null && prefix.length()>=3){
			correctPrefix = true;
		}

		File f = null;
		try{
			if(useParent){
				f = File.createTempFile(prefix, suffix, parent);
			}
			else {
				f = File.createTempFile(prefix, suffix);
			}
			check(prefix, suffix, "No IllegalArgumentException while prefix is not correct", correctPrefix);
		}
		catch(IllegalArgumentException e){
			check(prefix, suffix, "IllegalArgumentException while prefix is correct", !correctPrefix);
			return;
		}
		catch(NullPointerException e){
			check(prefix, suffix, "NullPointerException while prefix is correct", prefix==null);
			return;
		}

		check(prefix, suffix, "file is null", f != null);

		check(prefix, suffix, "temporary file already created", !CreatedFiles.contains(f));
		CreatedFiles.add(f);

		check(prefix, suffix, "exists", f.exists());
		check(prefix, suffix, "name does not start with prefix", f.getName().startsWith(prefix));

		if(suffix == null){
			suffix = ".tmp";
		}
		check(prefix, suffix, "name does not start with prefix", f.getName().endsWith(suffix));
		check(prefix, suffix, "At least five or more internally-generated characters", f.getName().length()>= (prefix.length()+5+suffix.length()));

		try(FileInputStream fis = new FileInputStream(f)){
			check(prefix, suffix, "file is not empty", fis.available()==0);
		}

		if(parent == null){
			parent = new File(System.getProperty("java.io.tmpdir"));
		}
		File actualParent = f.getParentFile();
		check(prefix, suffix, "wrong parent: "+actualParent, parent.equals(actualParent));
	}

	private static void check(String prefix, String suffix, String message, boolean assertion){
		CheckHelper.check(TestCreateTempFile.class, "Temp file prefix="+prefix+" suffix="+suffix+" "+message, assertion);
	}

	private static void clean(){
		for(File f : CreatedFiles){
			f.delete();
		}
	}
}
