/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#getAbsoluteFile()}.
 *
 * @author pgradot
 *
 */
public class TestGetAbsoluteFile {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestGetAbsoluteFile.class);
		test001();

		CheckHelper.endCheck(TestGetAbsoluteFile.class);
	}

	/**
	 * getAbsoluteFile() should be equivalent to File(getAbsolutePath()).
	 */
	private static void test001() {
		File f = new File("folder/subfolder/file");
		File expectedAbsolute = new File(f.getAbsolutePath());
		CheckHelper.check(TestGetAbsoluteFile.class, "getAbsoluteFile() should be equivalent to File(getAbsolutePath())",
				f.getAbsoluteFile().equals(expectedAbsolute));

		/*
		 * We know that our implementation of getAbsoluteFile() really returns new File(getAbsolutePath()), so more advanced tests are not needed
		 * here.
		 */
	}
}
