/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#getAbsolutePath()} that are Windows specific.
 *
 * @author pgradot
 *
 */
public class TestGetAbsolutePath_Windows {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestGetAbsolutePath_Windows ***");
		System.out.println(
				"This test can pass only if your platform has a WinNT file system. If your platform doesn't have a WinNT file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestGetAbsolutePath_Windows.class);
		test001();

		CheckHelper.endCheck(TestGetAbsolutePath_Windows.class);
	}

	/**
	 * 'C:\\folder\\file' should give the same string as it is already absolute.
	 */
	public static void test001() {
		String pathname = "C:\\folder\\file";
		File f = new File(pathname);
		CheckHelper.check(TestGetAbsolutePath_Windows.class, f + " should be absolute on Windows", f.isAbsolute());

		String absolute = f.getAbsolutePath();
		CheckHelper.check(TestGetAbsolutePath_Windows.class, pathname + " should give the same string as it is already absolute",
				absolute.equals(pathname));
	}

	// FIXME add tests for nominal case

}
