/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#getCanonicalFile()}.
 *
 * @author pgradot
 *
 */
public class TestGetCanonicalFile {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestGetCanonicalFile.class);
		test001();

		CheckHelper.endCheck(TestGetCanonicalFile.class);
	}

	/**
	 * getCanonicalFile() should be equivalent to File(getCanonicalPath()).
	 */
	private static void test001() {
		try {
			File f = new File("folder/subfolder/../file");
			File expectedCanonical = new File(f.getCanonicalPath());

			CheckHelper.check(TestGetAbsoluteFile.class, "getCanonicalFile() should be equivalent to File(getCanonicalPath())", f.getCanonicalFile()
					.equals(expectedCanonical));

		} catch (IOException e) {
			e.printStackTrace();
			CheckHelper.check(TestGetCanonicalFile.class, "Should not raise an IOException", false);
		}
		/*
		 * We know that our implementation of getCanonicalFile() really returns new File(getCanonicalPath()), so more advanced tests are not needed
		 * here.
		 */
	}
}