/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Test {@link File#getCanonicalPath()} with '..' on root.
 */
public class TestGetCanonicalPath2 {

	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestGetCanonicalPath2.class);

		//Retrieve the path to an existing root
		File[] roots = File.listRoots();
		String testRoot = null;
		for(File root : roots){
			if(root!=null && root.exists()){
				testRoot = root.getAbsolutePath();
				break;
			}
		}

		CheckHelper.check(TestGetCanonicalPath2.class, "No root found", testRoot != null);

		if(testRoot != null){
			String sep = File.separator;//Quick access to file separator

			//Force concatenation of separator at the end of the path
			if(!testRoot.endsWith(sep)){
				testRoot += sep;
			}


			try{
				testCanonicalPath(testRoot+"..", testRoot);
				testCanonicalPath(testRoot+".", testRoot);
				testCanonicalPath(testRoot+"foo"+sep+".."+sep+".."+sep+"bar", testRoot+"bar");
				testCanonicalPath(".."+sep+".."+sep+".."+sep+".."+sep+".."+sep+".."+sep+".."+sep+".."+sep+".."+sep+".."+sep, testRoot);
				testCanonicalPath(testRoot+"foo"+sep+".."+sep+"."+sep+".."+sep+"bar", testRoot+"bar");
			}
			catch(IOException e){
				CheckHelper.check(TestGetCanonicalPath2.class, "IOException", false);
				e.printStackTrace();
			}
		}

		CheckHelper.endCheck(TestGetCanonicalPath2.class);

	}

	public static void testCanonicalPath(String path, String expectedCanonicalPath) throws IOException{
		File f = new File(path);
		String canonicalPath = f.getCanonicalPath();

		CheckHelper.check(TestGetCanonicalPath2.class, "CanonicalPath of "+path, canonicalPath, expectedCanonicalPath);
	}

}
