/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#getCanonicalPath()} that are Windows specific.
 *
 * @author pgradot
 *
 */
public class TestGetCanonicalPath_Windows {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestGetCanonicalPath_Windows ***");
		System.out.println(
				"This test can pass only if your platform has a WinNT file system. If your platform doesn't have a WinNT file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestGetCanonicalPath_Windows.class);
		test001();
		test002();
		test003();
		test004();

		CheckHelper.endCheck(TestGetCanonicalPath_Windows.class);
	}

	/**
	 * The canonical path of 'C:\\folder\\subfolder\\file' should be 'C:\\folder\\subfolder\\file'.
	 */
	public static void test001() {
		String pathnameString = "C:\\folder\\subfolder\\file";
		String expectedCanonical = "C:\\folder\\subfolder\\file";

		try {
			File f = new File(pathnameString);
			String canonical = f.getCanonicalPath();

			CheckHelper.check(TestGetCanonicalPath_Windows.class, "The canonical path of " + pathnameString + " should be " + expectedCanonical,
					canonical.equals(expectedCanonical));

		} catch (IOException e) {
			e.printStackTrace();
			CheckHelper.check(TestGetCanonicalPath_Windows.class, "Get the canonical name of " + pathnameString + " should not raise an exception", false);
		}
	}

	/**
	 * The canonical path of 'C:\\folder\\.\\file' should be 'C:\\folder\\file'.
	 */
	public static void test002() {
		String pathnameString = "C:\\folder\\.\\file";
		String expectedCanonical = "C:\\folder\\file";

		try {
			File f = new File(pathnameString);
			String canonical = f.getCanonicalPath();

			CheckHelper.check(TestGetCanonicalPath_Windows.class, "The canonical path of " + pathnameString + " should be " + expectedCanonical,
					canonical.equals(expectedCanonical));

		} catch (IOException e) {
			e.printStackTrace();
			CheckHelper.check(TestGetCanonicalPath_Windows.class, "Get the canonical name of " + pathnameString + " should not raise an exception",
					false);
		}
	}

	/**
	 * The canonical path of 'C:\\folder\\..\\subfolder\\file' should be 'C:\\subfolder\\file'.
	 */
	public static void test003() {
		String pathnameString = "C:\\folder\\..\\subfolder\\file";
		String expectedCanonical = "C:\\subfolder\\file";

		try {
			File f = new File(pathnameString);
			String canonical = f.getCanonicalPath();

			CheckHelper.check(TestGetCanonicalPath_Windows.class, "The canonical path of " + pathnameString + " should be " + expectedCanonical,
					canonical.equals(expectedCanonical));

		} catch (IOException e) {
			e.printStackTrace();
			CheckHelper.check(TestGetCanonicalPath_Windows.class, "Get the canonical name of " + pathnameString + " should not raise an exception",
					false);
		}
	}

	/**
	 * The canonical path of 'C:\\folder\\subfolder\\..\\file' should be 'C:\\folder\\file'.
	 */
	public static void test004() {
		String pathnameString = "C:\\folder\\subfolder\\..\\file";
		String expectedCanonical = "C:\\folder\\file";

		try {
			File f = new File(pathnameString);
			String canonical = f.getCanonicalPath();

			CheckHelper.check(TestGetCanonicalPath_Windows.class, "The canonical path of " + pathnameString + " should be " + expectedCanonical,
					canonical.equals(expectedCanonical));

		} catch (IOException e) {
			e.printStackTrace();
			CheckHelper.check(TestGetCanonicalPath_Windows.class, "Get the canonical name of " + pathnameString + " should not raise an exception",
					false);
		}
	}
}
