/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.UtilTests;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#getName()}.
 *
 * @author pgradot
 *
 */
public class TestGetName {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestGetName.class);
		test001();
		test002();
		test003();
		test004();
		test005();

		test101();
		test103();
		test104();

		CheckHelper.endCheck(TestGetName.class);
	}

	private static final String EMPTY_STRING = "";

	/**
	 * An empty pathname string should result in the empty string.
	 */
	public static void test001() {
		File f = new File("");
		CheckHelper.check(TestGetName.class, "An empty pathname string should result in an empty string", EMPTY_STRING.equals(f.getName()));
	}

	/**
	 * "/" as pathname string should result in the empty string.
	 */
	public static void test002() {
		File f = new File("/");
		CheckHelper.check(TestGetName.class, "'/' as pathname string should result in the empty string", EMPTY_STRING.equals(f.getName()));
	}

	/**
	 * "\\" as pathname string should result in the empty string.
	 */
	public static void test003() {
		File f = new File("\\");
		if(UtilTests.onWindows()){
			CheckHelper.check(TestGetName.class, "'\\' as pathname string should result in the empty string", EMPTY_STRING.equals(f.getName()));
		}
		else {
			CheckHelper.check(TestGetName.class, "'\\' as pathname string should result in '\\'", "\\".equals(f.getName()));
		}
	}

	/**
	 * File.separator as pathname string should result in the empty string.
	 */
	public static void test004() {
		File f = new File(File.separator);
		CheckHelper.check(TestGetName.class, "File.separator as pathname string should result in the empty string", EMPTY_STRING.equals(f.getName()));
	}

	/**
	 * Several name separator as pathname string should result in the empty string.
	 */
	public static void test005() {
		File f = new File(File.separator + "/////" + "\\" + "/" + "\\\\" + File.separatorChar);
		if(UtilTests.onWindows()){
			CheckHelper.check(TestGetName.class, "Several name separator as pathname string should result in the empty string", EMPTY_STRING.equals(f.getName()));
		}
		else {
			CheckHelper.check(TestGetName.class, "Several name separator as pathname string should result in '\\\\'", "\\\\".equals(f.getName()));
		}
	}

	/**
	 * If the sequence name contains a single name, this name should be returned.
	 */
	public static void test101() {
		File f = new File("name");
		CheckHelper.check(TestGetName.class, "If the sequence name contains a single name, this name should be returned", "name".equals(f.getName()));
	}

	/**
	 * If the sequence name contains a single name and terminates with a name separator, this name should be returned.
	 */
	public static void test102() {
		File f = new File("name/");
		CheckHelper.check(TestGetName.class, "If the sequence name contains a single name and terminates with a name separator, this name should be returned",
				"name".equals(f.getName()));
	}

	/**
	 * The last name of a not empty name sequence should be returned.
	 */
	public static void test103() {
		File f = new File("A/B/C");
		CheckHelper.check(TestGetName.class, "The last name of a not empty name sequence should be returned", "C".equals(f.getName()));
	}

	/**
	 * The last name of a not empty name sequence should be returned, if even the sequence ends with a name separator.
	 */
	public static void test104() {
		File f = new File("A/B/C" + File.separator);
		CheckHelper.check(TestGetName.class, "The last name of a not empty name sequence should be returned, if even the sequence ends with a name separator",
				"C".equals(f.getName()));
	}

}
