/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#getParentFile()}.
 *
 * @author pgradot
 *
 */
public class TestGetParentFile {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestGetParentFile.class);
		test001();
		test002();
		test003();

		CheckHelper.endCheck(TestGetParentFile.class);
	}

	/**
	 * getParentFile() should return the abstract pathname of abstract pathname's parent, if the parent is not null.
	 */
	public static void test001() {
		File f = new File("folder/file");
		File parent = new File("folder");
		CheckHelper.check(TestGetParentFile.class,
				"getParentFile() should return the abstract pathname of abstract pathname's parent, if the parent is not null",
				parent.equals(f.getParentFile()));
	}

	/**
	 * getParentFile() should be equivalent to File(getParent()), if the parent is not null.
	 */
	public static void test002() {
		File f = new File("folder/file");
		File parent = new File(f.getParent());
		CheckHelper.check(TestGetParentFile.class,
				"getParentFile() should return the abstract pathname of abstract pathname's parent, if the parent is not null",
				parent.equals(f.getParentFile()));
	}

	/**
	 * getParentFile() should return null if this pathname does not name a parent directory.
	 */
	public static void test003() {
		File f = new File("file");
		CheckHelper
		.check(TestGetParentFile.class, "getParentFile() should return null if this pathname does not name a parent directory", f.getParentFile() == null);
	}

}
