/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

// FIXME write the same tests for UNIX

/**
 * Tests for {@link File#getParent()} that are specific for Windows.
 *
 */
public class TestGetParent_Windows {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestGetParent_Windows ***");
		System.out.println(
				"This test can pass only if your platform has a WinNT file system. If your platform doesn't have a WinNT file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestGetParent_Windows.class);
		test001();

		CheckHelper.endCheck(TestGetParent_Windows.class);
	}

	/**
	 * The parent of a simple path that starts with several name-separators should be "\\\\" (or '\\' --> double anti-slash) on Windows, because it
	 * denotes a UNC pathname.
	 */
	public static void test001() {
		File f = new File("////A");
		CheckHelper.check(TestGetParent.class, "The parent of a simple path that starts with several name-separators should be '\\' (1)",
				"\\\\".equals(f.getParent()));

		f = new File("\\\\\\B");
		CheckHelper.check(TestGetParent.class, "The parent of a simple path that starts with several name-separators should be '\\' (2)",
				"\\\\".equals(f.getParent()));

		f = new File(File.separator + File.separator + File.separator + "C");
		CheckHelper.check(TestGetParent.class, "The parent of a simple path that starts with several name-separators should be '\\' (3)",
				"\\\\".equals(f.getParent()));

		f = new File("\\//\\////\\\\//D");
		CheckHelper.check(TestGetParent.class, "The parent of a simple path that starts with several name-separators should be '\\' (4)",
				"\\\\".equals(f.getParent()));
	}

}
