/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#isAbsolute()}.
 *
 * @author pgradot
 *
 */
public class TestIsAbsolute {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestIsAbsolute.class);
		test001();
		test002();
		test003();

		CheckHelper.endCheck(TestIsAbsolute.class);
	}

	/**
	 * Roots should considered as absolute.
	 */
	public static void test001() {
		File[] roots = File.listRoots();
		for (int i = 0; i < roots.length; i++) {
			CheckHelper.check(TestIsAbsolute.class, "Root " + i + " should considered as being absolute", roots[i].isAbsolute());
		}
	}

	/**
	 * A pathname starting with one of the roots should be considered as absolute.
	 */
	public static void test002() {
		File[] roots = File.listRoots();
		File root0 = roots[0];

		File f = new File(root0, "A");
		CheckHelper.check(TestIsAbsolute.class, "A pathname starting with one of the roots should be considered as absolute 1", f.isAbsolute());

		f = new File(root0, "A/");
		CheckHelper.check(TestIsAbsolute.class, "A pathname starting with one of the roots should be considered as absolute 2", f.isAbsolute());

		f = new File(root0, "A/B");
		CheckHelper.check(TestIsAbsolute.class, "A pathname starting with one of the roots should be considered as absolute 3", f.isAbsolute());

		f = new File(root0, "A/B/C/");
		CheckHelper.check(TestIsAbsolute.class, "A pathname starting with one of the roots should be considered as absolute 4", f.isAbsolute());
	}

	/**
	 * 'C:' should be considered as not absolute (even on Windows).
	 */
	public static void test003() {
		File f = new File("C:");
		CheckHelper.check(TestIsAbsolute.class, "'C:' should be considered as not absolute", !f.isAbsolute());
		// FIXME this test fails if C:/ is a root
		/*
		 * Indeed, C:/ is normalized as C: so listRoot() gives C: as a root and isAbsolute things that C: is absolute...
		 */
	}

}
