/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for {@link File#isAbsolute()} that are specific for Windows.
 *
 * @author pgradot
 *
 */
public class TestIsAbsolute_Windows {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestIsAbsolute_Windows ***");
		System.out.println(
				"This test can pass only if your platform has a WinNT file system. If your platform doesn't have a WinNT file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestIsAbsolute_Windows.class);
		test001();
		test002();

		CheckHelper.endCheck(TestIsAbsolute_Windows.class);
	}

	/**
	 * 'C:\' should be considered as absolute on Windows (as well as file system using driver letters, such as Keil's).
	 *
	 * Note that 'C:' is not an absolute path on Windows (neither on UNIX) so there is no tests about it here. See {@link TestIsAbsolute} class.
	 */
	public static void test001() {
		File f = new File("C:\\");
		CheckHelper.check(TestIsAbsolute_Windows.class, "'C:\' should be considered as absolute on Windows", f.isAbsolute());
	}

	/**
	 * '/' should be considered as not absolute on Windows.
	 */
	public static void test002() {
		File f = new File("/");
		CheckHelper.check(TestIsAbsolute_Windows.class, "'/' should be considered as not absolute on Windows", !f.isAbsolute());
	}

}
