/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;
import com.microej.fs.tests.scenarios.tSuite;

/**
 * Test {@link File#list()} and {@link File#listFiles()} methods.
 */
public class TestList {

	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();

		CheckHelper.startCheck(TestList.class);
		try {

			// Init FS
			File root = new File(tSuite.tmp, "TestList");
			root.mkdirs();

			// Test on a file that does not exist
			File invalidDir = new File(root, "thisFileDoesNotExist");
			CheckHelper.check(TestList.class, "file does not exists", !invalidDir.exists());
			CheckHelper.check(TestList.class, "list is null for unavailable file", invalidDir.list() == null);
			CheckHelper.check(TestList.class, "listFiles is null for unavailable file", invalidDir.listFiles() == null);

			// Test on a file (not a directory)
			File file = new File(root, "imAFile");
			file.createNewFile();
			CheckHelper.check(TestList.class, "file is not a directory", file.isFile());
			CheckHelper.check(TestList.class, "list is null for file", file.list() == null);
			CheckHelper.check(TestList.class, "listFiles is null for file", file.listFiles() == null);

			// Test on an empty directory
			File emptyDir = new File(root, "emptyDir");
			boolean res = emptyDir.mkdir();
			CheckHelper.check(TestList.class, "empty directory created correctly", res);
			CheckHelper.check(TestList.class, "list is empty for an empty directory", emptyDir.list().length == 0);
			CheckHelper.check(TestList.class, "listFiles is empty for an empty directory", emptyDir.listFiles().length == 0);
			emptyDir.delete();

			// Test on non empty directory
			File dir = new File(root, "dir");
			res = dir.mkdir();
			CheckHelper.check(TestList.class, "directory created correctly", res);
			res = new File(dir, "test1").createNewFile();
			CheckHelper.check(TestList.class, "file test1 created correctly", res);
			res = new File(dir, "test2").createNewFile();
			CheckHelper.check(TestList.class, "file test2 created correctly", res);
			res = new File(dir, "test3").createNewFile();
			CheckHelper.check(TestList.class, "file test3 created correctly", res);

			CheckHelper.check(TestList.class, "list contains 3 files", dir.list().length == 3);
			CheckHelper.check(TestList.class, "listFiles contains 3 files", dir.listFiles().length == 3);

			for (File fileToDelete : dir.listFiles()) {
				fileToDelete.delete();
			}
			dir.delete();

		} catch (IOException e) {
			CheckHelper.check(TestList.class, "IOException", false);
			e.printStackTrace();
		}
		CheckHelper.endCheck(TestList.class);
	}

}
