/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.methods;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Test {@link File#listRoots()}. This test works even if there is
 * no root available.
 */
public class TestListRoot01 {

	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestListRoot01.class);
		File[] roots = File.listRoots();

		//Check if the root is not null because on Windows listRoots() may contains null values...
		if(roots != null){
			for(File root : roots){
				testRoot(TestListRoot01.class, root);
			}
		}

		CheckHelper.endCheck(TestListRoot01.class);
	}

	/**
	 * Tests that the given root file is valid.
	 * @param testClass the class of the test
	 * @param root {@link File} that references a root
	 */
	public static void testRoot(Class testClass, File root){
		CheckHelper.check(testClass, "root "+root+" is absolute", root.isAbsolute());
		String[] sfiles = root.list();
		File[] files = root.listFiles();
		if(root.exists()){
			CheckHelper.check(testClass, "root "+root+" exists", root.exists());
			CheckHelper.check(testClass, "root "+root+" is directory", root.isDirectory());

			CheckHelper.check(testClass, "listFiles is not null", files!=null);
			CheckHelper.check(testClass, "ist is not null", sfiles!=null);
			CheckHelper.check(testClass, "listFiles and list both return the same number of files", sfiles.length == files.length);
		}
		else {
			// The root does not exist! This may appear on windows for system partitions that are not accessible...
			CheckHelper.check(testClass, "root "+root+" is not a directory", !root.isDirectory());
			CheckHelper.check(testClass, "listFiles is null", files==null);
			CheckHelper.check(testClass, "list is null", sfiles==null);
		}
	}

}
