/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.properties;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests about the system properties that are necessary for a file system in Java.
 *
 * @author pgradot
 *
 */
public class TestSystemProperties {

	/**
	 * Entry point of the program to execute all theses tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		CheckHelper.startCheck(TestSystemProperties.class);
		test001();
		test002();
		test003();
		test004();

		CheckHelper.endCheck(TestSystemProperties.class);

	}

	/**
	 * "file.separator" should be set and should at least one-byte long.
	 */
	public static void test001() {
		String propertyName = "file.separator";

		String property = System.getProperty(propertyName);
		CheckHelper.check(TestSystemProperties.class, propertyName + " should be set", property != null);
		CheckHelper.check(TestSystemProperties.class, propertyName + " should at least one-byte long", property.length() >= 1);
	}

	/**
	 * "path.separator" should be set and should at least one-byte long.
	 */
	public static void test002() {
		String propertyName = "path.separator";

		String property = System.getProperty(propertyName);
		CheckHelper.check(TestSystemProperties.class, propertyName + " should be set", property != null);
		CheckHelper.check(TestSystemProperties.class, propertyName + " should at least one-byte long", property.length() >= 1);
	}

	/**
	 * "user.dir" should be set.
	 */
	public static void test003() {
		String propertyName = "user.dir";

		String property = System.getProperty(propertyName);
		CheckHelper.check(TestSystemProperties.class, propertyName + " should be set", property != null);

		// FIXME check for a minimal length?
	}

	/**
	 * "java.io.tmpdir" should be set.
	 */
	public static void test004() {
		String propertyName = "java.io.tmpdir";

		String property = System.getProperty(propertyName);
		CheckHelper.check(TestSystemProperties.class, propertyName + " should be set", property != null);

		// FIXME check for a minimal length?
	}

}
