/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

//import ej.sni.SNI;

public class TestFileAccess {

	public static void main(String[] args) throws InterruptedException{
		FileSystemCleaner.cleanFS();

		System.out.println("**************************");
		System.out.println("* FS : test on file acess*");
		System.out.println("**************************");

		Class tS = TestFileAccess.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestFileInputStream", TestFileInputStream());
		CheckHelper.check(tS,"TestFileOutputStream", TestFileOutputStream());
		CheckHelper.check(tS,"TestWrite", TestWrite());
		CheckHelper.check(tS,"TestRead", TestRead());
		CheckHelper.check(tS,"TestReadOffset", TestReadOffset());
		CheckHelper.check(tS,"TestWriteAppend", TestWriteAppend());
		CheckHelper.check(tS,"TestWriteOverwritten", TestWriteOverwritten());
		CheckHelper.check(tS,"TestWriteBigFile", TestWriteBigFile());
		CheckHelper.check(tS,"TestTempFile", TestTempFile());

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}
	/*
	 * FileInputStream : FileInputStream(File) & close()
	 */
	public static boolean TestFileInputStream() {
		System.out.println("**TestFileInputStream");
		boolean res = true;

		File file1 = new File(tSuite.testDisk, "G2T1fil1.txt");
		try {
			file1.createNewFile();
			// Open/Write/Close output stream
			FileInputStream fis1 = new FileInputStream(file1);
			fis1.close();
		} catch (IOException e) {
			res = false;
			e.printStackTrace();
		}
		file1.delete();
		return res;
	}

	/*
	 * FileOutputStream : FileOutputStream(File) & close()
	 */
	public static boolean TestFileOutputStream() {
		System.out.println("**TestFileOutputStream");
		boolean res = true;
		File file1 = new File(tSuite.testDisk, "G2T2fil1.txt");
		try {
			file1.createNewFile();
			// Open/Write/Close output stream
			FileOutputStream fos1 = new FileOutputStream(file1);
			fos1.close();
		} catch (IOException e) {
			res = false;
			e.printStackTrace();
		}

		file1.delete();
		return res;
	}

	/*
	 * TestWrite : write(int), write(byte[], int, int), read(byte[])
	 */
	public static boolean TestWrite() {
		System.out.println("**TestWrite");
		String s1 = "FatFs is a generic FAT file system module for small embedded systems.";
		File test4G2 = new File(tSuite.testDisk, "G2T4fil1.txt");
		boolean res = false;

		boolean comp = false;
		try {
			test4G2.createNewFile();
			byte[] byteTab = new byte[4];
			byteTab[0] = '0';
			byteTab[1] = '1';
			byteTab[2] = '2';
			byteTab[3] = '3';

			// Open/Write/Close output stream
			FileOutputStream fos1 = new FileOutputStream(test4G2, true);
			fos1.write(s1.getBytes(), 0, s1.length());
			fos1.write(byteTab);
			fos1.write('k');
			fos1.write('l');
			fos1.close();

			// Open/Read/Close input stream
			s1 = "FatFs is a generic FAT file system module for small embedded systems.0123kl";
			FileInputStream fis1 = new FileInputStream(test4G2);
			byte[] data = new byte[s1.length() + 1];
			int readByte = fis1.read(data, 0, data.length - 1);
			String s = new String(data);

			comp = s.equals(s1 + "\0");
			fis1.close();
			if (comp == true ) {
				res = true;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		test4G2.delete();
		return res;
	}

	/*
	 * TestRead : read() byte by byte
	 */
	public static boolean TestRead() {
		System.out.println("**TestRead");
		String s1 = "coucou";
		File file123 = new File(tSuite.testDisk, "G2T5fil1.txt");
		boolean res = false;

		try {
			file123.createNewFile();

			// Open/Write/Close output stream
			FileOutputStream fos3 = new FileOutputStream(file123);
			fos3.write(s1.getBytes(), 0, s1.length());
			fos3.close();
			// Open/Read/Close input stream
			FileInputStream fis3 = new FileInputStream(file123);
			if (fis3.read() == 'c' && fis3.read() == 'o' && fis3.read() == 'u'
					&& fis3.read() == 'c' && fis3.read() == 'o'
					&& fis3.read() == 'u' && fis3.read() == -1) {
				res = true;
			}
			fis3.close();
			file123.delete();

		} catch (IOException e) {
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * TestReadOffset : read() offset
	 */
	public static boolean TestReadOffset() {
		System.out.println("**TestReadOffset");
		String s1 = "123456";
		byte[] data=s1.getBytes();
		File file1 = new File(tSuite.testDisk, "G2T6fil1.txt");
		boolean res = false;

		try {
			file1.createNewFile();

			// Open/Write/Close output stream
			FileOutputStream fos4 = new FileOutputStream(file1);
			fos4.write(data, 0, data.length);
			fos4.close();

			// Open/Read/Close input stream;
			FileInputStream fis4 = new FileInputStream(file1);
			fis4.read(data, 3, 3);
			String dataString = new String(data);
			if (dataString.equals("123123")) {
				res = true;
			}
			fis4.close();
			file1.delete();

		} catch (IOException e) {
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * TestWriteAppend : append mode
	 */
	public static boolean TestWriteAppend() {
		System.out.println("**TestWriteAppend");
		String s1 = "123456";
		String s2 = "abcde";
		File append = new File(tSuite.testDisk, "G2T7fil1.txt");
		boolean res = false;

		try {
			append.createNewFile();
			// Open/Write/Close output stream

			FileOutputStream fos1 = new FileOutputStream(append, false);
			fos1.write(s1.getBytes());
			fos1.close();

			// Open/Write/Close output stream
			FileOutputStream fos2 = new FileOutputStream(append, true);
			fos2.write(s2.getBytes());
			fos2.close();

			// Open/Read/Close input stream
			FileInputStream fis1 = new FileInputStream(append);
			byte[] data = new byte[12];
			fis1.read(data, 0, 11);
			String dataString = new String(data);
			if (dataString.equals("123456abcde\0")) {
				res = true;
			}
			fis1.close();
			append.delete();

		} catch (IOException e) {
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * TestWriteOverwritten : normal write mode. When existing  file is open with normal write mode (output stream, without append option), it have to be clean of
	 * all data.
	 */
	public static boolean TestWriteOverwritten() {
		System.out.println("**TestWriteOverwritten");

		File file = new File(tSuite.testDisk, "TestWriteOverwritten.txt");
		boolean res = false;

		try {
			file.createNewFile();
			// Open/Write/Close output stream

			FileOutputStream fos1 = new FileOutputStream(file, false);
			fos1.write("0123456789".getBytes());
			fos1.close();

			// Open/Write/Close output stream
			FileOutputStream fos2 = new FileOutputStream(file, false);
			fos2.write("abc".getBytes());
			fos2.close();

			// Open/Read/Close input stream
			FileInputStream fis = new FileInputStream(file);
			byte[] data = new byte[12];
			fis.read(data, 0, 11);

			String dataString = new String(data);
			if (dataString.startsWith("abc\0")) {
				res = true;
			}
			fis.close();
			file.delete();

		} catch (IOException e) {
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * TestWriteBigFile : Write and read data longer than immortal buffer length and test return value.
	 */
	public static boolean TestWriteBigFile() throws InterruptedException {
		System.out.println("**TestWriteBigFile");

		File file = new File(tSuite.testDisk, "bigFile.txt");
		boolean res = false;

		try {
			file.createNewFile();
			FileOutputStream fos = new FileOutputStream(file, false);
			fos.write(System.getProperty("bigData").getBytes());
			fos.close();

			FileInputStream fis = new FileInputStream(file);
			byte[] data = new byte[System.getProperty("bigData").length()+1];
			fis.read(data, 0, System.getProperty("bigData").length()+1);

			String dataString = new String(data);
			if (dataString.startsWith(System.getProperty("bigData")+"\0")) {
				res = true;
			}

			fis.close();
			file.delete();

		} catch (IOException e) {
			e.printStackTrace();
			res = false;
		}
		return res;
	}

	/*
	 * TestTempFile
	 */
	public static boolean TestTempFile() {
		System.out.println("**TestTempFile");

		String tmp = System.getProperty("tmpdir");
		File tmpDir = new File(tmp, "mauve-testdir");

		if (!tmpDir.exists() && !tmpDir.mkdirs()) {
			System.out.println("tmpDir creation failed");
			return false;
		}

		File tmpFile = null;

		// Test : null prefix
		boolean resPrefix = false;
		try {
			tmpFile = File.createTempFile(null, null, tmpDir);
			tmpFile.delete();
		} catch (NullPointerException e) {
			resPrefix = true;
		} catch (IOException e) {
		}

		// Test : null suffix (makes the file ends with .tmp
		boolean resSuffix = false;

		try {
			tmpFile = File.createTempFile("mauve-testfile", null, tmpDir);
			if (tmpFile != null) {
				resSuffix = tmpFile.getName().endsWith(".tmp");
				tmpFile.delete();
			}

		} catch (IOException e1) {
			e1.printStackTrace();
		} catch (NullPointerException e) {
			System.out.println("in null pointer exception");
		}

		// Test : not null suffix & prefix
		boolean resSufPre = false;
		try {
			String prefix = "prefix";
			String suffix = "suffix";

			tmpFile = File.createTempFile(prefix, suffix, tmpDir);
			if (tmpFile.exists() && tmpFile.getName().startsWith(prefix) && tmpFile.getName().endsWith(suffix)) {
				resSufPre = true;
				tmpFile.delete();
			}
		} catch (IOException e) {
		}
		// tmpFile.delete();
		tmpDir.delete();

		// Result :
		if (resPrefix && resSuffix && resSufPre) {
			return true;
		} else {
			return false;
		}
	}

}
