/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Calendar;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestFileProperties {

	public static void main(String[] args) throws InterruptedException, FileNotFoundException{
		FileSystemCleaner.cleanFS();

		System.out.println("*****************************");
		System.out.println("* FS : test file properties *");
		System.out.println("*****************************");

		Class tS = TestFileProperties.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestGetAbsolutePath", TestGetAbsolutePath());
		CheckHelper.check(tS,"TestGetParentAndName", TestGetParentAndName());
		CheckHelper.check(tS,"TestIsProperties", TestIsProperties());
		CheckHelper.check(tS,"TestLastModifiedTime", TestLastModifiedTime());
		CheckHelper.check(tS,"TestRename", TestRename());
		CheckHelper.check(tS,"TestSpaceFunction", TestSpaceFunction());
		TestRelativePath();

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * TestGetAbsolutePath : getAbsolutePath()
	 * getCanonicalFile()
	 */
	public static boolean TestGetAbsolutePath() {
		System.out.println("**TestGetAbsolutePath");
		// TODO complete with all get path function
		boolean res = false;
		File dir1 = new File(tSuite.testDisk, "G3T1dir1");
		File dir2 = new File(dir1, "G3T1dir2");
		File file1 = new File(dir2, "G3T1fil1.txt");
		File file2 = new File(tSuite.testDisk + File.separator + "G3T1dir1" + File.separator + "G3T1dir2" + File.separator
				+ "G3T1fil1.txt");


		try {
			dir1.mkdir();
			dir2.mkdir();
			file1.createNewFile();
			if (file1.getAbsolutePath().equals(file2.getAbsolutePath())) {
				res = true;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		dir2.delete();
		dir1.delete();
		return res;
	}

	/*
	 * TestGetParentAndName
	 */
	public static boolean TestGetParentAndName() {
		System.out.println("**TestGetParentAndName");
		boolean res = false;

		File dir1 = new File(tSuite.testDisk, "G3T2dir1");
		File dir2 = new File(tSuite.testDisk, "G3T2dir1"
				+ File.separator + "G3T2dir2");
		File file1 = new File(tSuite.testDisk, "G3T2dir1"
				+ File.separator + "G3T2dir2" + File.separator
				+ "G3T2fil1.txt");

		File dir = new File("mauve");
		File file = new File(dir, "mauve");

		try {
			dir1.mkdir();
			dir2.mkdir();

			file1.createNewFile();

			dir.mkdir();
			file.createNewFile();

			File parent = file.getParentFile();

			String fileName = file1.getName();
			String parentPath = file1.getParent();
			String filePath = file1.getPath();
			File parentFile = file1.getParentFile();

			if (parentFile.getPath().equals(dir2.getPath())
					&& filePath.equals(new File(tSuite.testDisk + File.separator + "G3T2dir1" + File.separator + "G3T2dir2" + File.separator
							+ "G3T2fil1.txt").getPath())
					&& parentPath.equals(new File(tSuite.testDisk + File.separator + "G3T2dir1" + File.separator + "G3T2dir2").getPath())
					&& fileName.equals("G3T2fil1.txt")
					&& dir.getPath().equals(parent.getPath())) {
				res = true;
			}

		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		dir2.delete();
		dir1.delete();
		file.delete();
		dir.delete();

		return res;
	}

	/*
	 * TestIsProperties
	 */
	public static boolean TestIsProperties() {
		System.out.println("**TestIsProperties");
		boolean res = false;
		File dir1 = new File(tSuite.testDisk, "G3T3dir1");
		File file1 = new File(tSuite.testDisk, "G3T3dir1"
				+ File.separator + "G3T3fil1.txt");
		try {
			dir1.mkdir();
			file1.createNewFile();
			if (file1.isFile() && dir1.isDirectory()
					&& file1.isDirectory() == false && dir1.isFile() == false
					&& dir1.isAbsolute() && file1.isAbsolute()
					&& file1.isHidden() == false) {
				res = true;
			}

		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		dir1.delete();
		return res;
	}

	/*
	 * TestLastModifiedTime
	 */
	public static boolean TestLastModifiedTime() {
		System.out.println("**TestLastModifiedTime");
		boolean res = false;
		File dir1 = new File(tSuite.testDisk, "G3T4dir1");
		File file1 = new File(tSuite.testDisk, "G3T4dir1"
				+ File.separator + "G3T4fil1.txt");
		try {

			dir1.mkdir();
			file1.createNewFile();
			Calendar date = Calendar.getInstance();
			// Update file date to 5th May 2014 at 15:30:40
			date.set(2014, 4, 5, 15, 30, 40);
			long ref = date.getTimeInMillis();
			file1.setLastModified(ref);
			long get = file1.lastModified();
			if ((ref >= (get - 1000))&&(ref <= (get + 1000))) {// Date comparison between 1 second shift
				res = true;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		dir1.delete();
		return res;
	}

	/*
	 * Test005 : renameTo(File dest), length(), toString()
	 */
	public static boolean TestRename() {
		System.out.println("**TestRename");
		boolean res = false;
		File dir2 = new File(tSuite.testDisk, "G3T5dir2");
		File file1 = new File(tSuite.testDisk, "G3T5dir2"
				+ File.separator + "G3T5fil1.txt");
		File renameFile1 = new File(tSuite.testDisk, "G3T5dir2"
				+ File.separator + "G3T5rnm.txt");
		String s1 = "123456789";

		try {
			dir2.mkdir();
			file1.createNewFile();
			FileOutputStream fos1 = new FileOutputStream(file1);
			fos1.write(s1.getBytes(), 0, s1.length());
			fos1.close();

			boolean ren = file1.renameTo(renameFile1);

			if (file1.toString().equals(file1.getPath())
					&& renameFile1.length() == 9 && ren == true) {
				res = true;
			}

		} catch (IOException e) {
			e.printStackTrace();
		}
		renameFile1.delete();
		dir2.delete();
		return res;
	}

	/*
	 * TestSpaceFunction
	 */
	public static boolean TestSpaceFunction() {
		System.out.println("**TestSpaceFunction");
		boolean res = false;
		File dir2 = new File(tSuite.testDisk, "G3T6dir2");
		File file1 = new File(tSuite.testDisk, "G3T6dir2"
				+ File.separator + "G3T6fil1.txt");

		try {
			dir2.mkdir();
			file1.createNewFile();

			long freeS = file1.getFreeSpace();
			long totalS = file1.getTotalSpace();
			long usableS = file1.getUsableSpace();

			if (freeS > 0 && totalS > 0 && usableS > 0) {
				res = true;
			}

		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		dir2.delete();
		return res;
	}

	/*
	 * TestRelativePath
	 */
	public static void TestRelativePath() {
		System.out.println("**TestRelativePath");
		String usr = System.getProperty("user.dir");

		try {
			String SEPARATOR = File.separator;
			File file = new File("tmp");
			CheckHelper.check(TestFileProperties.class, "Relative path "+file+" not correct",
					file.getPath().equals("tmp")
					&& file.getCanonicalPath().endsWith(usr+SEPARATOR+"tmp")
					&& file.getParent() == null);


			file = new File("tmp"+SEPARATOR);
			CheckHelper.check(TestFileProperties.class, "Relative path "+file+" not correct",
					file.getPath().equals("tmp")
					&& file.getCanonicalPath().endsWith(usr+SEPARATOR+"tmp")
					&& file.getParent() == null);

			file = new File("tmp"+SEPARATOR+"tmp2"+SEPARATOR);
			CheckHelper.check(TestFileProperties.class, "Relative path "+file+" not correct",
					file.getPath().equals("tmp"+SEPARATOR+"tmp2")
					&& file.getCanonicalPath().endsWith(usr+SEPARATOR+"tmp"+SEPARATOR+"tmp2")
					&& file.getParent().equals("tmp"));

			file = new File("tmp"+SEPARATOR+"tmp2");
			CheckHelper.check(TestFileProperties.class, "Relative path "+file+" not correct",
					file.getPath().equals("tmp"+SEPARATOR+"tmp2")
					&& file.getCanonicalPath().endsWith(usr+SEPARATOR+"tmp"+SEPARATOR+"tmp2")
					&& file.getParent().equals("tmp"));


			file = new File("tmp"+SEPARATOR+SEPARATOR);
			CheckHelper.check(TestFileProperties.class, "Relative path "+file+" not correct",
					file.getPath().equals("tmp")
					&& file.getCanonicalPath().endsWith(usr+SEPARATOR+"tmp")
					&& file.getParent() == null);

		} catch (IOException e1) {

			e1.printStackTrace();
		}

	}
}
