/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileFilter;
import java.io.FilenameFilter;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestListAndCompare {

	public static void main(String[] args) throws InterruptedException{
		FileSystemCleaner.cleanFS();

		System.out.println("******************************");
		System.out.println("* FS : test list and compare *");
		System.out.println("******************************");

		Class tS = TestListAndCompare.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestList", TestList());
		CheckHelper.check(tS,"TestCompareTo", TestCompareTo());
		CheckHelper.check(tS,"TestEqual", TestEqual());
		CheckHelper.check(tS,"TestListWithFilter", TestListWithFilter());

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * TestList
	 */
	public static boolean TestList() {
		System.out.println("**TestList");
		boolean res = false;
		File dir1 = new File(tSuite.testDisk, "G4T1dir1");
		File dir11 = new File(dir1, "G4T1DIR2");
		File file1 = new File(dir1, "G4T1FIL1.TXT");

		try {
			if (dir1.mkdir() && dir11.mkdir() && file1.createNewFile())
			{
				String[] list = dir1.list();
				File[] listFile = dir1.listFiles();
				File[] listRoot = File.listRoots();
				// TODO not the better way to test those methods
				if (list.length > 1 && listFile.length > 1 && listRoot.length >= 1) {
					res = true;
				}
				for (int i = listFile.length - 1; i >= 0; i--) {
					File file = listFile[i];
					// ensure parent folder and current folder are not listed
					if (".".equals(file.getName()) || "..".equals(file.getName())) {
						res = false;
					}
				}
			}
			else
			{
				res = false;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		dir11.delete();
		dir1.delete();
		return res;
	}



	/*
	 * compareTo(Object other)
	 */
	public static boolean TestCompareTo() {
		System.out.println("**TestCompareTo");
		boolean res = false;
		File file1 = new File(tSuite.testDisk, "TestCompareTofil1.txt");
		File file2 = new File(tSuite.testDisk, "TestCompareTofil1.txt");
		File file3 = new File(tSuite.testDisk, "TestCompareTofil2.txt");
		File file4 = new File(tSuite.testDisk, "TestCompareTofil0.txt");

		try {
			file1.createNewFile();
			file3.createNewFile();
			file4.createNewFile();
		} catch (IOException e) {
			System.out.println("fail creation file.");
		}

		// Compare file1 with itself, file2 (same path), file3 ('lower' path),
		// file4 ('greater' path) and compare to itself (object cast).


		if (file1.compareTo(file1) == 0 && file1.compareTo(file2) == 0 && file1.compareTo(file3) < 0 && file1.compareTo(file4) > 0) {
			res = true;
		}

		file1.delete();
		file3.delete();
		file4.delete();
		return res;
	}



	/*
	 * TestEqual
	 */
	public static boolean TestEqual() {
		System.out.println("**TestEqual");
		File file1 = new File("TestEqualfil.txt");
		Object o = new Object();
		if (!file1.equals(o)) {
			return true;
		} else {
			return false;
		}

	}

	/*
	 * TestListWithFilter
	 */
	public static boolean TestListWithFilter() {
		System.out.println("**TestListWithFilter");
		boolean resNameFilter = false;
		boolean resEmptyDir = false;
		boolean resFileFilter = false;
		boolean resFileFilter2 = false;
		// Setup
		String tmp = tSuite.tmp;
		File tmpDir = new File(tmp + File.separator + "mauve-testdir");
		File emptyDir = new File(tmp + File.separator + "mauve-testdir" + File.separator + "empty");
		tmpDir.mkdir();
		emptyDir.mkdir();
		File tmpFile = null;
		File tmpFile2 = null;
		try {

			tmpFile = new File(tmpDir, "mauve-testfile");
			tmpFile.createNewFile();
			tmpFile2 = new File(tmpDir, "mauve-testfile2");
			tmpFile2.createNewFile();

			// FILE FILTER
			// Only "mauve-testfile2" should be returned
			FileFilter filterOne = new FileFilter() {
				@Override
				public boolean accept(File pathname) {
					if (pathname.getName().equals("mauve-testfile2")) {
						return true;
					}
					return false;
				}
			};
			File[] fileList = tmpDir.listFiles(filterOne);
			if (fileList != null && fileList.length == 1 && fileList[0].getName().equals("mauve-testfile2")) {
				resFileFilter = true;
			}

			// FILENAME FILTER

			// Only "mauve-testfile2" should be returned
			FilenameFilter filenameFilterOne = new FilenameFilter() {
				@Override
				public boolean accept(File dir, String name) {
					if (dir.getName().startsWith("mauve-testdir") && name.equals("mauve-testfile2")) {
						return true;
					}
					return false;
				}
			};

			File[] fileList2 = tmpDir.listFiles(filenameFilterOne);
			for (File f : fileList2) {
			}
			if (fileList2 != null && fileList2.length == 1 && fileList2[0].getName().equals("mauve-testfile2")) {
				resFileFilter2 = true;
			}
			String[] filenameList = tmpDir.list(filenameFilterOne);
			for (String s : filenameList) {
			}
			if (filenameList != null && filenameList.length == 1 && filenameList[0].equals("mauve-testfile2")) {
				resNameFilter = true;
			}

			// Check on an empty dir that the list() method return an empty
			// array
			String[] filenameEmptyList = emptyDir.list(filenameFilterOne);
			for (String s : filenameEmptyList) {
			}
			if (filenameEmptyList != null && filenameEmptyList.length == 0) {
				resEmptyDir = true;
			}

		} catch (IOException e) {
			System.out.println("IOException");
		}

		// Cleanup

		emptyDir.delete();
		tmpFile.delete();
		if(tmpFile2 != null){
			tmpFile2.delete();
		}
		tmpDir.delete();
		if (resNameFilter && resFileFilter && resFileFilter2 && resEmptyDir) {
			return true;
		} else {
			return false;
		}
	}


}
