/*
 * Java
 *
 * Copyright 2014-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestMultipleStreamOnSameFile {

	public static void main(String[] args) throws InterruptedException{
		FileSystemCleaner.cleanFS();

		System.out.println("******************************************");
		System.out.println("* FS : test multiple stream on same file *");
		System.out.println("******************************************");

		Class tS = TestMultipleStreamOnSameFile.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestOneStreamInAndOut", TestOneStreamInAndOut());
		CheckHelper.check(tS,"TestOneStreamOutAndSomeIn", TestOneStreamOutAndSomeIn());
		CheckHelper.check(tS,"TestOneStreamInAndOpenClose", TestOneStreamInAndOpenClose());
		CheckHelper.check(tS,"TestOneStreamInAndOpenCloseNotAppend", TestOneStreamInAndOpenCloseNotAppend());
		CheckHelper.check(tS,"TestMultipleStreamIn", TestMultipleStreamIn());
		CheckHelper.check(tS,"TestMultipleStreamOut", TestMultipleStreamOut());

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * TestOneStremInAndOut
	 */
	public static boolean TestOneStreamInAndOut() {
		System.out.println("**TestOneStreamInAndOut");

		File file = new File(tSuite.testDisk, "TestOneStreamInAndOut.txt");
		byte[] dataRead = new byte[11];

		boolean res = true;
		try {
			file.createNewFile();

			// 1.Open output stream on file
			FileOutputStream fos1 = new FileOutputStream(file);

			// 2. Write "0123456789"
			fos1.write("0123456789".getBytes());
			fos1.flush();

			// 3.Open second stream on same file
			FileInputStream fis1 = new FileInputStream(file);

			// 4.Read 4 byte, should be "0123"
			int biteReadden = 0;
			biteReadden = fis1.read(dataRead, 0, 5);
			String dataS1 = new String(dataRead);
			// String dataS1 = SNI.toJavaString(dataRead);
			if (biteReadden != 5 || !dataS1.startsWith("01234")) {
				System.out.println("a");
				res = false;
			}

			// 5.Write another time "abcdefgh"
			fos1.write("abcdefgh".getBytes());
			fos1.flush();

			// 6.Read second time 10 bytes. Should be "56789abcde"
			biteReadden = fis1.read(dataRead, 0, 10);
			String dataS2 = new String(dataRead);
			// String dataS2 = SNI.toJavaString(dataRead);
			if (biteReadden != 10 || !dataS2.startsWith("56789abcde")) {
				System.out.println("b");
				res = false;
			}

			// 7.Close output stream
			fos1.close();

			// 8.Read last time 10 byte, Should be only : "fgh" and biteReadden= -1
			byte[] dataRead2 = new byte[11];
			biteReadden = fis1.read(dataRead2, 0, 10);
			String dataS3 = new String(dataRead2);
			// String dataS3 = SNI.toJavaString(dataRead2);
			if (biteReadden != 3 || !dataS3.startsWith("fgh")) {
				System.out.println("c : " + dataS3);
				res = false;
			}

			// 9. close input stream
			fis1.close();

		} catch (IOException e) {
			e.printStackTrace();
			res = false;
		}
		file.delete();
		return res;
	}

	/*
	 * TestOneStreamOutAndSomeIn
	 */
	public static boolean TestOneStreamOutAndSomeIn() {
		System.out.println("**TestOneStreamOutAndSomeIn");
		File file = new File(tSuite.testDisk, "TestOneStreamOutAndSomeIn.txt");
		if (file.exists()) {
			file.delete();
		}

		boolean res = true;

		byte[] dataRead = new byte[20];
		try {
			file.createNewFile();
			// File and output stream creation
			FileOutputStream fos = new FileOutputStream(file);

			// Write in file : 'abcdefghi'
			fos.write("abcdefghi".getBytes());
			fos.flush();

			// File input stream creation
			FileInputStream fis = new FileInputStream(file);

			// First read : should be 'abcdefghi'
			int byteReadden1 = 0;
			byteReadden1 = fis.read(dataRead, 0, 19);
			if (byteReadden1 != 9) {
				res = false;
			}

			// second read : should be null
			int byteReadden2 = 0;
			byteReadden2 = fis.read(dataRead, 0, 19);
			if (byteReadden2 != -1) {
				res = false;
			}

			// second write : 'jklmnop'
			fos.write("jklmnop".getBytes());
			fos.flush();

			// third read : should be 'jklmnop'
			int byteReadden3 = 0;
			byteReadden3 = fis.read(dataRead);
			if (byteReadden3 != 7) {
				res = false;
			}

			// fifth read : should be null
			int byteReadden4 = 0;
			byteReadden4 = fis.read(dataRead);
			if (byteReadden4 != -1) {
				res = false;
			}

			// Close stream
			fis.close();
			fos.close();

		} catch (IOException e) {
			e.printStackTrace();
			res = false;
		}
		file.delete();
		return res;
	}

	/*
	 * TestOneStreamInAndOpenClose
	 */
	public static boolean TestOneStreamInAndOpenClose() {
		System.out.println("**TestOneStreamInAndOpenClose");

		File file = new File(tSuite.testDisk, "TestOneStreamInAndOpenClose.txt");
		int byteReadden = 0;
		boolean res = true;
		try {
			file.createNewFile();
			FileOutputStream fos1 = new FileOutputStream(file);

			FileInputStream fis1 = new FileInputStream(file);

			// Write 1
			byte[] dataWrite1 = "0123456789".getBytes();
			fos1.write(dataWrite1);
			fos1.flush();

			// Read 1
			byte[] dataRead1 = new byte[6];
			byteReadden = fis1.read(dataRead1, 0, 5);
			String dataS1 = new String(dataRead1);
			if (!dataS1.startsWith("01234")) {
				System.out.println("1");
				res = false;
			}

			// Read 2
			byte[] dataRead2 = new byte[5];
			byteReadden = fis1.read(dataRead2, 0, 2);
			String dataS2 = new String(dataRead2);
			if (!dataS2.startsWith("56")) {
				System.out.println("2");
				res = false;
			}

			// Read 3
			byte[] dataRead3 = new byte[6];
			byteReadden = fis1.read(dataRead3, 0, 5);
			String dataS3 = new String(dataRead3);
			if (!dataS3.startsWith("789")) {
				System.out.println("3");
				res = false;
			}

			// Read 4
			byte[] dataRead4 = new byte[6];
			byteReadden = fis1.read(dataRead4, 0, 5);
			if (byteReadden != -1) {
				System.out.println("4");
				res = false;
			}

			// Write 2
			byte[] dataWrite2 = "abcdefghijk".getBytes();
			fos1.write(dataWrite2);
			fos1.flush();

			// Read 5
			byte[] dataRead5 = new byte[5];
			byteReadden = fis1.read(dataRead5, 0, 4);
			String dataS5 = new String(dataRead5);
			if (!dataS5.startsWith("abcd")) {
				System.out.println("5");
				res = false;
			}

			// Read 6
			byte[] dataRead6 = new byte[5];
			byteReadden = fis1.read(dataRead6, 0, 4);
			String dataS6 = new String(dataRead6);
			if (!dataS6.startsWith("efgh")) {
				System.out.println("6");
				res = false;
			}

			// Write 3
			//byte[] dataWrite3 = ",;:!*-+?./§µ".getBytes();
			byte[] dataWrite3 = ",;:!*-+?./gfyr".getBytes();
			fos1.write(dataWrite3);
			fos1.flush();

			// Read 7
			byte[] dataRead7 = new byte[6];
			byteReadden = fis1.read(dataRead7, 0, 5);
			String dataS7 = new String(dataRead7);
			if (!dataS7.startsWith("ijk,;")) {
				System.out.println("7");
				res = false;
			}

			// Read 8
			byte[] dataRead8 = new byte[6];
			byteReadden = fis1.read(dataRead8, 0, 5);
			String dataS8 = new String(dataRead8);
			if (!dataS8.startsWith(":!*-+")) {
				System.out.println("8");
				res = false;
			}

			// Close input Stream & re-open it.
			fis1.close();
			FileInputStream fis2 = new FileInputStream(file);

			// ReRead 1
			byte[] dataReRead1 = new byte[6];
			byteReadden = fis2.read(dataReRead1, 0, 3);
			String dataSS1 = new String(dataReRead1);
			if (!dataSS1.startsWith("012")) {
				System.out.println("9");
				res = false;
			}

			// Close output Stream & re-open it. In Append mode.
			fos1.close();
			FileOutputStream fos2 = new FileOutputStream(file, true);

			// ReRead 2
			byte[] dataReRead2 = new byte[6];
			byteReadden = fis2.read(dataReRead2, 0, 3);
			String dataSS2 = new String(dataReRead2);
			if (!dataSS2.startsWith("345")) {
				System.out.println("10");
				res = false;
			}

			// ReWrite 1
			//byte[] dataReWrite1 = "éééé".getBytes();
			byte[] dataReWrite1 = "plokijuh".getBytes();
			fos2.write(dataReWrite1);
			fos2.flush();

			// ReRead 3
			byte[] dataReRead3 = new byte[37];
			byteReadden = fis2.read(dataReRead3, 0, 37);
			String dataSS3 = new String(dataReRead3);
			//if (!dataSS3.startsWith("6789abcdefghijk,;:!*-+?./§µplokijuh")) {
			if (!dataSS3.startsWith("6789abcdefghijk,;:!*-+?./gfyrplokijuh")) {
				System.out.println("11");
				res = false;
			}

			// ReWrite 2
			//byte[] dataReWrite2 = "èèèè".getBytes();
			byte[] dataReWrite2 = "paozieur".getBytes();
			fos2.write(dataReWrite2);
			fos2.flush();

			// ReRead 4
			byte[] dataReRead4 = new byte[8];
			byteReadden = fis2.read(dataReRead4, 0, 8);
			String dataSS4 = new String(dataReRead4);
			//if (!dataSS4.startsWith("èèèè")) {
			if (!dataSS4.startsWith("paozieur")) {
				System.out.println("12");
				res = false;
			}

			// ReRead 5
			byte[] dataReRead5 = new byte[6];
			byteReadden = fis2.read(dataReRead5, 0, 5);
			if (byteReadden != -1) {
				System.out.println("13");
				res = false;
			}

			fis2.close();
			fos2.close();

		} catch (IOException e) {
			e.printStackTrace();
			res = false;
		}
		file.delete();
		return res;
	}

	/*
	 * TestOneStreamInAndOpenCloseNotAppend
	 */
	public static boolean TestOneStreamInAndOpenCloseNotAppend() {
		System.out.println("**TestOneStreamInAndOpenCloseNotAppend");

		File file = new File(tSuite.testDisk, "TestOneStreamInAndOpenCloseNotAppend.txt");
		int byteReadden = 0;
		boolean res = true;
		try {
			file.createNewFile();
			FileOutputStream fos1 = new FileOutputStream(file);

			FileInputStream fis1 = new FileInputStream(file);

			// Write 1
			byte[] dataWrite1 = "0123456789".getBytes();
			fos1.write(dataWrite1);
			fos1.flush();

			// Read 1
			byte[] dataRead1 = new byte[6];
			byteReadden = fis1.read(dataRead1, 0, 5);
			String dataS1 = new String(dataRead1, 0, byteReadden);
			if (!dataS1.startsWith("01234")) {
				System.out.println("1");
				res = false;
			}

			// Read 2
			byte[] dataRead2 = new byte[5];
			byteReadden = fis1.read(dataRead2, 0, 2);
			String dataS2 = new String(dataRead2, 0, byteReadden);
			if (!dataS2.startsWith("56")) {
				System.out.println("2");
				res = false;
			}

			// Read 3
			byte[] dataRead3 = new byte[6];
			byteReadden = fis1.read(dataRead3, 0, 5);
			String dataS3 = new String(dataRead3, 0, byteReadden);
			if (!dataS3.startsWith("789")) {
				System.out.println("3");
				res = false;
			}

			// Read 4
			byte[] dataRead4 = new byte[6];
			byteReadden = fis1.read(dataRead4, 0, 5);
			if (byteReadden != -1) {
				System.out.println("4");
				res = false;
			}

			// Write 2
			byte[] dataWrite2 = "abcdefghijk".getBytes();
			fos1.write(dataWrite2);
			fos1.flush();

			// Read 5
			byte[] dataRead5 = new byte[5];
			byteReadden = fis1.read(dataRead5, 0, 4);
			String dataS5 = new String(dataRead5, 0, byteReadden);
			if (!dataS5.startsWith("abcd")) {
				System.out.println("5");
				res = false;
			}

			// Read 6
			byte[] dataRead6 = new byte[5];
			byteReadden = fis1.read(dataRead6, 0, 4);
			String dataS6 = new String(dataRead6, 0, byteReadden);
			if (!dataS6.startsWith("efgh")) {
				System.out.println("6");
				res = false;
			}

			// Write 3
			byte[] dataWrite3 = ",;:!*-+?./§µ".getBytes();
			fos1.write(dataWrite3);
			fos1.flush();

			// Read 7
			byte[] dataRead7 = new byte[6];
			byteReadden = fis1.read(dataRead7, 0, 5);
			String dataS7 = new String(dataRead7, 0, byteReadden);
			if (!dataS7.startsWith("ijk,;")) {
				System.out.println("7");
				res = false;
			}

			// Read 8
			byte[] dataRead8 = new byte[6];
			byteReadden = fis1.read(dataRead8, 0, 5);
			String dataS8 = new String(dataRead8, 0, byteReadden);
			if (!dataS8.startsWith(":!*-+")) {
				System.out.println("8");
				res = false;
			}

			// Close input Stream & re-open it.
			fis1.close();
			FileInputStream fis2 = new FileInputStream(file);

			// ReRead 1
			byte[] dataReRead1 = new byte[6];
			byteReadden = fis2.read(dataReRead1, 0, 3);
			String dataSS1 = new String(dataReRead1, 0, byteReadden);
			if (!dataSS1.startsWith("012")) {
				System.out.println("9");
				res = false;
			}


			// Close output Stream & re-open it. In not Append mode.
			fos1.close();
			FileOutputStream fos2 = new FileOutputStream(file, false);

			// Check if available() does not return negative value
			if (fis2.available() < 0) {
				res = false;
			}

			// ReRead 2
			byte[] dataReRead2 = new byte[6];
			byteReadden = fis2.read(dataReRead2, 0, 3);
			// read may return buffered data
			// in this case, check if the data read is the one that have been previously
			// written.
			if (byteReadden > 0) {
				String dataSS2 = new String(dataReRead2, 0, byteReadden);

				if (!dataSS2.startsWith("3")) {
					System.out.println("10");
					res = false;
				}

				if (byteReadden > 1 && !dataSS2.startsWith("34")) {
					System.out.println("11");
					res = false;
				}

				if (byteReadden > 2 && !dataSS2.equals("345")) {
					System.out.println("12");
					res = false;
				}
			}
			fis2.close();
			fos2.close();

		} catch (IOException e) {
			e.printStackTrace();
			res = false;
		}
		file.delete();
		return res;
	}

	/*
	 * TestMultipleStreamIn
	 */
	public static boolean TestMultipleStreamIn() {
		System.out.println("**TestMultipleStreamIn");
		boolean res = false;
		File file = new File(tSuite.testDisk, "TestMultipleStreamIn.txt");
		if (file.exists()) {
			file.delete();
		}
		try {
			file.createNewFile();
			FileOutputStream fos = new FileOutputStream(file);
			fos.write("0123456789".getBytes());
			fos.close();

			FileInputStream fis1 = new FileInputStream(file);
			int read1 = fis1.read();

			FileInputStream fis2 = new FileInputStream(file);
			int read2 = fis2.read();

			fis1.close();

			int read3 = fis2.read();

			fis2.close();
			if ((read1 == read2) && ((read2 + 1) == read3)) {
				res = true;
			}

		} catch (IOException e) {
			return false;
		} catch (IndexOutOfBoundsException e) {
			return false;
		}

		file.delete();
		return res;


	}

	/*
	 * TestMultipleStreamOut
	 */
	public static boolean TestMultipleStreamOut()  {
		System.out.println("**TestMultipleStreamOut");
		boolean res = false;

		File file = new File(tSuite.testDisk, "TestMultipleStreamOut.txt");
		if (file.exists()) {
			file.delete();
		}
		try {
			file.createNewFile();

			FileOutputStream fos1 = new FileOutputStream(file);
			fos1.write(0);
			fos1.flush();

			FileOutputStream fos2 = new FileOutputStream(file,true );
			fos2.write(1);
			fos1.close();

			fos2.write(2);
			fos2.close();

			FileInputStream fis = new FileInputStream(file);
			if (fis.read() == 0 && fis.read() == 1 && fis.read() == 2) {
				res = true;
			}
			fis.close();
		} catch (IOException e) {
			res = false;
		}

		file.delete();
		return res;
	}

}
