/*
 * Java
 *
 * Copyright 2014-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestMultipleThreadOnMultipleFile {

	public static void main(String[] args) throws InterruptedException, IOException{
		FileSystemCleaner.cleanFS();

		System.out.println("*************************************");
		System.out.println("* FS : Multithread on multiple file *");
		System.out.println("*************************************");

		Class tS = TestMultipleThreadOnMultipleFile.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestMultipleThreadWriteOnMultipleFile", TestMultipleThreadWriteOnMultipleFile());


		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * TestMultipleThreadOnMultipleFile
	 */
	public static boolean TestMultipleThreadWriteOnMultipleFile() throws IOException {
		System.out.println("**TestMultipleThreadWriteOnMultipleFile");

		File file_t1 = new File(tSuite.testDisk, "TestMultipleThreadWriteOnMultipleFile_T1.txt");
		File file_t2 = new File(tSuite.testDisk, "TestMultipleThreadWriteOnMultipleFile_T2.txt");
		if (file_t1.exists()) {
			file_t1.delete();
		}
		if (file_t2.exists()) {
			file_t2.delete();
		}
		try {
			file_t1.createNewFile();
			file_t2.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
		}


		String data1 = "abcdefghijklmnopqrstuvwxyz";
		String data2 = "zyxwvutsrqponmlkjihgfedcba";

		FileOutputStream fos_t1 = null, fos_t2 = null;
		try {
			fos_t1 = new FileOutputStream(file_t1, true);
			fos_t2 = new FileOutputStream(file_t2, true);
		} catch (FileNotFoundException e1) {
			e1.printStackTrace();
		}
		FsWriteThread thread1 = new FsWriteThread(fos_t1, data1, 10);
		FsWriteThread thread2 = new FsWriteThread(fos_t2, data2, 10);

		thread1.start();
		thread2.start();

		try {
			thread1.join();
			thread2.join();
		} catch (Exception e) {
			e.printStackTrace();
		}

		fos_t1.close();
		fos_t2.close();

		long length_f1 = file_t1.length();
		long length_f2 = file_t2.length();

		file_t1.delete();
		file_t2.delete();

		if ((length_f1 == 260) && ((length_f2 == 260))) {
			return true;
		} else {
			return false;
		}
	}
}
