/*
 * Java
 *
 * Copyright 2014-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestMultipleThreadOnSameFile {

	public static void main(String[] args) throws InterruptedException{
		FileSystemCleaner.cleanFS();

		System.out.println("*********************************");
		System.out.println("* FS : Multithread on same file *");
		System.out.println("*********************************");

		Class tS = TestMultipleThreadOnSameFile.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestMultipleThreadWriteWithOneStream", TestMultipleThreadWriteWithOneStream());
		CheckHelper.check(tS,"TestMultipleThreadWriteWithMultipleStreamNotInterruptable", TestMultipleThreadWriteWithMultipleStreamNotInterruptable());
		CheckHelper.check(tS,"TestMultipleThreadWriteWithMultipleStreamInterruptable", TestMultipleThreadWriteWithMultipleStreamInterruptable());
		CheckHelper.check(tS,"TestMultipleThreadWriteAndReadWithMultipleStream", TestMultipleThreadWriteAndReadWithMultipleStream());
		CheckHelper.check(tS,"TestMultipleThreadReadWithMultipleStream", TestMultipleThreadReadWithMultipleStream());

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * TestMultipleThreadWriteWithOneStream
	 */
	public static boolean TestMultipleThreadWriteWithOneStream() {
		System.out.println("**TestMultipleThreadWriteWithOneStream");

		File file = new File(tSuite.testDisk, "TestMultipleThreadWriteWithOneStream.txt");
		if (file.exists()) {
			file.delete();
		}
		try {
			file.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
		}
		String data1 = "1111111111"; // 10 bytes
		String data2 = "2222222222"; // 10 bytes
		String data3 = "3333333333"; // 10 bytes
		FileOutputStream fos = null;
		try {
			fos = new FileOutputStream(file, true);
		} catch (FileNotFoundException e1) {
			e1.printStackTrace();
		}
		FsWriteThread thread1 = new FsWriteThread(fos, data1, 100); // write data1 100 times
		FsWriteThread thread2 = new FsWriteThread(fos, data2, 100); // write data2 100 times
		FsWriteThread thread3 = new FsWriteThread(fos, data3, 100); // write data3 100 times

		thread1.start();
		thread2.start();
		thread3.start();

		try {
			thread1.join();
			thread2.join();
			thread3.join();
			fos.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
		long length = file.length();

		file.delete();

		if (length == 3000) {
			return true;
		} else {
			return false;
		}
	}

	/*
	 * TestMultipleThreadWriteWithMultipleStreamNotInterruptable
	 */
	public static boolean TestMultipleThreadWriteWithMultipleStreamNotInterruptable() {
		System.out.println("**TestMultipleThreadWriteWithMultipleStreamNotInterruptable");

		File file2 = new File(tSuite.testDisk, "TestMultipleThreadWriteWithMultipleStreamNotInterruptable.txt");
		if (file2.exists()) {
			file2.delete();
		}
		try {
			file2.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
		}
		String data1 = "1111111111"; // 10 bytes
		String data2 = "2222222222"; // 10 bytes
		String data3 = "3333333333"; // 10 bytes

		FsWriteThread2 thread1 = new FsWriteThread2(file2, data1, 20); // write data1 20 times
		FsWriteThread2 thread2 = new FsWriteThread2(file2, data2, 20); // write data2 20 times
		FsWriteThread2 thread3 = new FsWriteThread2(file2, data3, 20); // write data3 20 times

		thread1.start();
		thread2.start();
		thread3.start();

		try {
			thread1.join();
			thread2.join();
			thread3.join();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
		long length = file2.length();

		file2.delete();

		if (length == 600) {
			return true;
		} else {
			return false;
		}
	}

	/*
	 * TestMultipleThreadWriteWithMultipleStreamInterruptable
	 */
	public static boolean TestMultipleThreadWriteWithMultipleStreamInterruptable() {
		System.out.println("**TestMultipleThreadWriteWithMultipleStreamInterruptable");

		File file3 = new File(tSuite.testDisk, "TestMultipleThreadWriteWithMultipleStreamInterruptable.txt");
		if (file3.exists()) {
			file3.delete();
		}
		try {
			file3.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
		}
		String data1 = "1111111111"; // 10 bytes
		String data2 = "2222222222"; // 10 bytes
		String data3 = "3333333333"; // 10 bytes

		FsWriteThread3 thread1 = new FsWriteThread3(file3, data1, 100); // write data1 100 times
		FsWriteThread3 thread2 = new FsWriteThread3(file3, data2, 100); // write data2 100 times
		FsWriteThread3 thread3 = new FsWriteThread3(file3, data3, 100); // write data3 100 times

		thread1.start();
		thread2.start();
		thread3.start();

		try {
			thread1.join();
			thread2.join();
			thread3.join();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
		long length = file3.length();

		file3.delete();

		if (length == 3000) {
			return true;
		} else {
			return false;
		}

	}

	/*
	 * TestMultipleThreadWriteAndReadWithMultipleStream
	 */
	public static boolean TestMultipleThreadWriteAndReadWithMultipleStream() {
		System.out.println("**TestMultipleThreadWriteAndReadWithMultipleStream");

		File file4 = new File(tSuite.testDisk, "TestMultipleThreadWriteAndReadWithMultipleStream.txt");
		if (file4.exists()) {
			file4.delete();
		}
		try {
			file4.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
			return false;
		}

		String data2 = "2222222222"; // 10 bytes
		String data3 = "3333333333"; // 10 bytes

		FsReadThread thread1 = new FsReadThread(file4, 10, 100); // read 10 bytes 100 times
		FsWriteThread3 thread2 = new FsWriteThread3(file4, data2, 100); // write data2 100 times
		FsWriteThread2 thread3 = new FsWriteThread2(file4, data3, 100); // write data3 100 times


		thread2.start();
		thread3.start();
		thread1.start();

		try {
			thread1.join();
			thread2.join();
			thread3.join();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
		long length = file4.length();

		file4.delete();

		if (length == 2000) {
			return true;
		} else {
			return false;
		}

	}

	/*
	 * TestMultipleThreadReadWithMultipleStream
	 */
	public static boolean TestMultipleThreadReadWithMultipleStream() {
		System.out.println("**TestMultipleThreadReadWithMultipleStream");

		File file5 = new File(tSuite.testDisk, "TestMultipleThreadReadWithMultipleStream.txt");
		if (file5.exists()) {
			file5.delete();
		}

		try {
			file5.createNewFile();
			FileOutputStream fos = new FileOutputStream(file5);
			fos.write("Bonjour, je test la lecture en multi thread".getBytes());
			fos.close();
		} catch (IOException e) {
			e.printStackTrace();
		}


		byte[] data1 = new byte[6];
		byte[] data2 = new byte[6];

		FsReadThread2 thread1 = new FsReadThread2(file5, data1, 8);
		FsReadThread3 thread2 = new FsReadThread3(file5, data2, 8);

		thread1.start();
		thread2.start();

		try {
			thread1.join();
			thread2.join();

		} catch (InterruptedException e) {
			e.printStackTrace();
		}

		file5.delete();

		if (thread1.getReturn() && thread2.getReturn()) {
			return true;
		} else {
			return false;
		}

	}

}
