/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.IOException;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

public class TestPathAndDir {

	public static void main(String[] args){
		FileSystemCleaner.cleanFS();

		System.out.println("**************************");
		System.out.println("* FS : test on path & dir*");
		System.out.println("**************************");

		Class tS = TestPathAndDir.class;
		CheckHelper.startCheck(tS);

		/* test suite */
		CheckHelper.check(tS,"TestMkDir", TestMkDir());
		CheckHelper.check(tS,"TestMkDirMkDir", TestMkDirMkDir());
		CheckHelper.check(tS,"TestCreateNewFile", TestCreateNewFile());
		CheckHelper.check(tS,"TestDeleteAndExist", TestDeleteAndExist());
		CheckHelper.check(tS,"TestCreateWithWrongParameter", TestCreateWithWrongParameter());
		CheckHelper.check(tS,"TestRandomSeparator", TestRandomSeparator());
		CheckHelper.check(tS,"TestBasicPath", TestBasicPath());

		System.out.println("");
		System.out.println("______________");
		CheckHelper.endCheck(tS);
	}

	/*
	 * Test001 : Test mkdir() without recursion
	 */
	public static boolean TestMkDir() {
		System.out.println("**TestMkDir");
		boolean res = false;
		File dir1 = new File(tSuite.testDisk, "dir1");
		res = dir1.mkdir();
		return res;
	}

	/*
	 * Test002 : Test mkdir() & mkdirs() with recursion
	 */
	public static boolean TestMkDirMkDir() {
		System.out.println("**TestMkDirMkDir");
		boolean res = false;
		File dir1 = new File(tSuite.testDisk, "dir1");
		File dir2 = new File(dir1, "dir2");
		File dirA = new File(tSuite.testDisk, "dira");
		File dirB = new File(dirA, "dirb");
		File dirC = new File(tSuite.testDisk, "dirc");

		boolean res1, res2, res3, res4;

		res3 = dirA.mkdir();
		res1 = dirC.mkdir();
		res2 = dir2.mkdir();
		res4 = dirB.mkdir();

		// Setup
		String tmp = System.getProperty("java.io.tmpdir");
		File tmpDir = new File(tmp + File.separator + "mauve-testdir");
		tmpDir.mkdir();

		File tmpDir2 = new File(tmpDir, "mauve-testdir2");
		File tmpDir3 = new File(tmpDir2, "mauve-testdir3");
		File tmpDirNoParent = new File(tmp + File.separator + "mauve-testdir4");

		boolean resMkdirs = false;
		boolean resMkdirsEmpty = false;
		resMkdirs = tmpDir3.mkdirs();
		resMkdirsEmpty = tmpDirNoParent.mkdirs();

		if (res1 && res2 && res3 && res4 && resMkdirs && resMkdirsEmpty) {
			res = true;
		}
		tmpDirNoParent.delete();
		tmpDir3.delete();
		tmpDir2.delete();

		return res;
	}

	/*
	 * Test003 : Test createNewFile()
	 */
	public static boolean TestCreateNewFile() {
		System.out.println("**TestCreateNewFile");
		boolean res = false;
		boolean res1 = false, res2 = false;
		File file1 = new File(tSuite.testDisk, "file1.txt");
		File dirC = new File(tSuite.testDisk, "dirc");
		File file2 = new File(dirC, "file2.txt");
		try {
			res1 = file1.createNewFile();
			res2 = file2.createNewFile();
			if (res1 && res2) {
				res = true;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * Test004 : Test delete() & exist()
	 */
	public static boolean TestDeleteAndExist() {
		System.out.println("**TestDeleteAndExist");
		boolean res = false;
		File file1 = new File(tSuite.testDisk, "file1.txt");
		File dir1 = new File(tSuite.testDisk, "dir1");
		File dir2 = new File(dir1, "dir2");
		File dirA = new File(tSuite.testDisk, "dira");
		File dirB = new File(dirA, "dirb");
		File dirC = new File(tSuite.testDisk, "dirc");
		File file2 = new File(dirC, "file2.txt");

		Boolean delete1 = file2.delete();
		Boolean delete2 = file1.delete();
		Boolean delete3 = dirC.delete();
		Boolean delete4 = dirB.delete();
		Boolean delete5 = dirA.delete();
		Boolean delete6 = dir2.delete();
		Boolean delete7 = dir1.delete();

		if (delete1 && delete2 && delete3 && delete4 && delete5 && delete6
				&& delete7) {
			res = true;
		}
		return res;
	}

	/*
	 * Test005 : File constructor with null arguments
	 */
	public static boolean TestCreateWithWrongParameter() {
		System.out.println("**TestCreateWithWrongParameter");
		boolean resNullDir = false;
		boolean resNullName = false;
		boolean resEmptyDir = false;

		// with null dir
		try {
			File file = new File((File) null, "mauve-testfile");

			resNullDir = true;
		} catch (NullPointerException npe) {
			System.out.println("e");
		}

		// With empty string as dir
		try {
			File f2 = new File("", "mauve-testfile");
			resEmptyDir = true;
		} catch (NullPointerException e) {
			System.out.println("e");
		}

		// With null name
		try {
			File f1 = new File("mauve-testdir", null);
		} catch (NullPointerException npe) {
			resNullName = true;
		}

		if (resNullDir && resNullName && resEmptyDir) {
			return true;
		} else {
			return false;
		}
	}

	/*
	 * Test006 : Ramdom file SEPARATOR (Slash & back slash)
	 */
	public static boolean TestRandomSeparator() {
		System.out.println("**TestRandomSeparator");
		boolean res = false;
		File dir1 = new File(tSuite.testDisk + "/G1T6dir1");
		File dir2 = new File(tSuite.testDisk + "\\G1T6dir2");
		File file1 = new File(dir1.getAbsolutePath() + "\\G3T2fil1.txt");
		File file2 = new File(dir2.getAbsolutePath() + "/G3T2fil2.txt");
		try {
			if (dir1.mkdir() && dir2.mkdir() && file1.createNewFile()
					&& file2.createNewFile()) {
				res = true;
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		file1.delete();
		file2.delete();
		dir1.delete();
		dir2.delete();
		return res;
	}

	/*
	 * Test007 : Some basics tests on path.
	 */
	public static boolean TestBasicPath() {
		System.out.println("**TestBasicPath");
		String originalPath = "test//../test2";
		File f = new File(originalPath);

		String expectedPath = "test/../test2".replace("/", File.separator);

		if (f.getPath().equals(expectedPath) && f.isAbsolute() == false) {
			return true;
		} else {
			return false;
		}

	}


}
