/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for GenericFileSystem.normalizePath(). This class is not visible here, because we compile against the API, not the implementation. We know
 * that the path is normalized in the constructor of File and that this normalized path is returned by getPath(), so we can trick.
 *
 */
public class TestPathNormalization2_Unix {

	/**
	 * Entry point with all the tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestPathNormalization2_Unix ***");
		System.out.println(
				"This test can pass only if your platform has a UNIX file system. If your platform doesn't have a UNIX file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestPathNormalization2_Unix.class);

		// Normalization is based on the name separator, check its length
		CheckHelper.check(TestPathNormalization2_Unix.class, "File.separator should be '/'", File.separator.equals("/"));

		// Check normalization
		File f;
		String normalized;

		f = new File("/a\\b/c\\");
		normalized = "/a\\b/c\\";
		CheckHelper.check(TestPathNormalization2_Unix.class, "Path not correctly normalized (0)", normalized.equals(f.getPath()));

		f = new File("\\a\\b\\c");
		normalized = "\\a\\b\\c";
		CheckHelper.check(TestPathNormalization2_Unix.class, "Path not correctly normalized (1)", normalized.equals(f.getPath()));

		f = new File("/a\\\\\\\\b\\\\c\\\\\\\\d/////\\\\/");
		normalized = "/a\\\\\\\\b\\\\c\\\\\\\\d/\\\\";
		CheckHelper.check(TestPathNormalization2_Unix.class, "Path not correctly normalized (2)", normalized.equals(f.getPath()));

		// Done \o/
		CheckHelper.endCheck(TestPathNormalization2_Unix.class);
	}

}
