/*
 * Java
 * 
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;

import com.is2t.testsuite.support.CheckHelper;
import com.microej.fs.tests.helpers.FileSystemCleaner;

/**
 * Tests for GenericFileSystem.normalizePath(). This class is not visible here, because we compile against the API, not the implementation. We know
 * that the path is normalized in the constructor of File and that this normalized path is returned by getPath(), so we can trick.
 *
 */
public class TestPathNormalization_Windows {

	/**
	 * Entry point with all the tests.
	 *
	 * @param args
	 *            not used
	 */
	public static void main(String[] args) {
		FileSystemCleaner.cleanFS();
		System.out.println("*** TestPathNormalization_Windows ***");
		System.out.println(
				"This test can pass only if your platform has a WinNT file system. If your platform doesn't have a WinNT file system, you can safely exclude this test from the tests set.");
		CheckHelper.startCheck(TestPathNormalization_Windows.class);

		// Normalization is based on the name separator, check its length
		CheckHelper.check(TestPathNormalization_Windows.class, "File.separator should be one byte long", File.separator.length() == 1);
		CheckHelper.check(TestPathNormalization_Windows.class, "File.separator should be a String represenation of File.separatorChar",
				File.separator.equals(String.valueOf(File.separatorChar)));

		// Check normalization
		File f;
		String normalized;

		f = new File("C:/a\\b/c\\");
		normalized = "C:" + File.separator + "a" + File.separator + "b" + File.separator + "c";
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (0)", normalized.equals(f.getPath()));

		f = new File("C:/a/b/c");
		normalized = "C:" + File.separator + "a" + File.separator + "b" + File.separator + "c";
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (1)", normalized.equals(f.getPath()));

		f = new File("C:///A//B////////C//////////D/");
		normalized = "C:" + File.separator + "A" + File.separator + "B" + File.separator + "C" + File.separator + "D";
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (2)", normalized.equals(f.getPath()));

		f = new File("C:\\a\\b\\c");
		normalized = "C:" + File.separator + "a" + File.separator + "b" + File.separator + "c";
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (3)", normalized.equals(f.getPath()));

		f = new File("C:/a\\\\\\\\b\\\\c\\\\\\\\d/////\\\\/");
		normalized = "C:" + File.separator + "a" + File.separator + "b" + File.separator + "c" + File.separator + "d";
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (4)", normalized.equals(f.getPath()));

		f = new File("C:" + File.separator + File.separator + File.separator + "A" + File.separator + "B" + File.separator + File.separator);
		normalized = "C:" + File.separator + "A" + File.separator + "B";
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (5)", normalized.equals(f.getPath()));

		f = new File("C:/");
		normalized = "C:" + File.separator;
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (6)", normalized.equals(f.getPath()));

		f = new File("C:\\");
		normalized = "C:" + File.separator;
		CheckHelper.check(TestPathNormalization_Windows.class, "Path not correctly normalized (7)", normalized.equals(f.getPath()));

		// Done \o/
		CheckHelper.endCheck(TestPathNormalization_Windows.class);
	}

}
