/*
 * Java
 *
 * Copyright 2014-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

public class speedTest {

	private static final int loopNb = 100;
	/*
	 * Test001 : Native Bench Write. This test create a file (speedtest.txt) and write in it all data in properties file. To compare performance, you
	 * have to implement the same test in C. Open/Write/Close include in time.
	 */
	public static boolean test001() {
		System.out.println("**Java bench Open/Write/Close");
		boolean res = true;
		try {

			long time = 0;
			long moyTime = 0;
			String data = System.getProperty("data");
			File file1 = new File(tSuite.testDisk, "speedWriteTestJava.txt");
			file1.createNewFile();


			long timeStart = System.currentTimeMillis();

			for (int loop = 0; loop < loopNb; loop++) {

				// Open/Write/Close output stream
				FileOutputStream fos1 = new FileOutputStream(file1);
				fos1.write(data.getBytes());
				fos1.close();

				// file1.delete();

			}
			time = System.currentTimeMillis() - timeStart;
			moyTime = time / loopNb;
			System.out.println("MoyTime : " + moyTime);
		} catch (IOException e) {
			res = false;
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * Test002 : Native Bench Write. This test create a file (speedtest.txt) and write in it all data in properties file. To compare performance, you
	 * have to implement the same test in C. only Write include in time.
	 */
	public static boolean test002() {
		System.out.println("**Java bench write");
		boolean res = true;
		try {

			long time = 0;
			long moyTime = 0;
			String data = System.getProperty("data");
			File file1 = new File(tSuite.testDisk, "speedWriteTestJava2.txt");
			file1.createNewFile();

			// Open/Write/Close output stream
			FileOutputStream fos1 = new FileOutputStream(file1);

			long timeStart = System.currentTimeMillis();

			for (int loop = 0; loop < loopNb; loop++) {
				fos1.write(data.getBytes());
			}
			time = System.currentTimeMillis() - timeStart;
			fos1.close();

			// file1.delete();
			moyTime = time / loopNb;
			System.out.println("MoyTime : " + moyTime);
		} catch (IOException e) {
			res = false;
			e.printStackTrace();
		}
		return res;
	}

	/*
	 * Test003 : Native Bench Read. Open/Read/Close include in time.
	 */
	public static boolean test003() {
		System.out.println("**jave bench Open/Read/Close");
		boolean res = true;
		try {
			long time = 0;
			long moyTime = 0;
			File file1 = new File(tSuite.testDisk, "speedWriteTestJava.txt");
			if (file1.exists()) {
				byte[] dataRead = new byte[1024];
				int byteRead = 0;
				long timeStart = System.currentTimeMillis();
				for (int loop = 0; loop < loopNb; loop++) {
					FileInputStream fis1 = new FileInputStream(file1);
					byteRead = byteRead + fis1.read(dataRead, 0, 1024);
					fis1.close();
				}
				time = System.currentTimeMillis() - timeStart;
				moyTime = time / loopNb;
				System.out.println("byteRead : "+byteRead);
				System.out.println("moytime : "+moyTime);
			}
		} catch (IOException e) {
			res = false;
			e.printStackTrace();
		}

		return res;
	}

	/*
	 * Test004 : Native Bench Read. Only Read include in time.
	 */
	public static boolean test004() {
		System.out.println("**jave bench Read");
		boolean res = true;
		try {

			long time = 0;
			long moyTime = 0;
			File file1 = new File(tSuite.testDisk, "speedWriteTestJava2.txt");
			if (file1.exists()) {
				byte[] dataRead = new byte[1025];
				int byteRead = 0;
				FileInputStream fis1 = new FileInputStream(file1);
				long timeStart = System.currentTimeMillis();
				for (int loop = 0; loop < loopNb; loop++) {
					// Open/Write/Close output stream
					byteRead = byteRead + fis1.read(dataRead, 0, 1024);
					// offset < 0 || length < 0 || length > (data.length - offset)
				}
				time = System.currentTimeMillis() - timeStart;
				moyTime = time / loopNb;

				fis1.close();
				System.out.println("byteRead : " + byteRead);
				System.out.println("moytime : " + moyTime);
			}
		} catch (IOException e) {
			res = false;
			e.printStackTrace();
		}

		return res;
	}
}
