/*
 * Java
 *
 * Copyright 2014-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.fs.tests.scenarios;

import java.io.File;
import java.io.IOException;

//import java.io.IOException;

/**
 * <b>***** Test Suite for FS API *****</b>
 * <P>
 * Don't forget to mount file system on disk. More details in the implementation of IFileSystem for the choose file system. To run test suite, you
 * must comment/uncomment proper line in properties file of the test project
 * <P>
 * UPDATE :
 * <P>
 * In case of update of this TestSuite, always validate it with openJDK implementation. To do that, put all files of fs-embedded-test in openJDK
 * project and, change testDisk and tmp path with valid path.
 * <p>
 * Test suite is split in 6 groups of tests.
 * <ul>
 * <li>TestGroup 1 : 7 tests
 * <ul>
 * <li>Test 1 : mkdir() without recursion
 * <li>Test 2 : mkdir() & mkdirs() with recursion
 * <li>Test 3 : createNewFile()
 * <li>Test 4 : delete() & exist()
 * <li>Test 5 : null argument
 * <li>Test 6 : wrong SEPARATOR
 * <li>Test 7 : basics path tests
 * </ul>
 * <li>TestGroup 2 : 7 tests
 * <ul>
 * <li>Test 1 : FileInputStream(File) & close()
 * <li>Test 2 : FileOutputStream(File) & close()
 * <li>Test 3 : Others constructor and few stream open in the same time.
 * <li>Test 4 : write(int), write(byte[], int, int), readChar(int, int) & readByte(byte[])
 * <li>Test 5 : read() byte by byte
 * <li>Test 6 : read() offset
 * <li>Test 7 : append mode
 * <li>Test 8 : open in normal write mode
 * <li>Test 9 : 'big' file
 * </ul>
 * <li>TestGroup 3 : 6 tests
 * <ul>
 * <li>Test 1 : getAbsolutePath(), getAbsoluteFile(), getCanonicalPath(), getCanonicalFile()
 * <li>Test 2 : getName(), getParentFile(), getPath(), getParent()
 * <li>Test 3 : isAbsolute(), isDirectory(), isFile(), isHidden()
 * <li>Test 4 : lastModified(), setLastModified(long time)
 * <li>Test 5 : renameTo(File dest), length(), toString()
 * <li>Test 6 : getTotalSpace(), getFreeSpace(),getUsableSpace()
 * <li>Test 7 : relative path
 *
 * </ul>
 * <li>TestGroup 4 : 4 tests
 * <ul>
 * <li>Test 1 : list(), listFiles(), listRoots().
 * <li>Test 2 : setReadOnly().
 * <li>Test 3 : compareTo(Object other)
 * <li>Test 4 : createTempFile(String prefix,String suffix, File directory), createTempFile(String prefix, String suffix)
 * <li>Test 5 : equal
 * <li>Test 6 : list() & listFile() with fileFilter & fileNameFilter
 * <li>Test 7 : list() & listFile()
 * </ul>
 * <li>TestGroup 6 : 4 tests (Multi-Stream)
 * <ul>
 * <li>Test 1 : multiple stream on one file (one input and one output)
 * <li>Test 2 : end of file with multiple stream (one input and one output)
 * <li>Test 3 : Keep on stream open, and open/close few time another one on same file. (one input and one output)
 * <li>Test 4 : In normal write mode. When file is reopen, it should be clean.
 * <li>Test 5 : Multiple input stream on same file (in the same thread)
 * <li>Test 6 : Multiple output stream on same file (in the same thread)
 *
 * </ul>
 * <li>TestGroup 7 : 6 tests (Multi-thread)
 * <ul>
 * <li>Test 1 : write in file in multi-thread. Create file and open stream. Start 3 different threads. test final length file.
 * <li>Test 2 : Test to write in file in multi-thread. Create file. Start 3 different threads, open stream write in file and close it. test final
 * length file.
 * <li>Test 3 : write in file in multi-thread. Create file. Start 3 different threads, open stream write in file and close it. test final length file.
 * <li>Test 4 : one thread read, an other write and last one open/write/close file.
 * <li>Test 5 : one thread read, and an other stream open/read/close file (should read always the same thing)
 * <li>Test 6 : actualisation of file access if it is open only in read mode by one thread and another thread open it in write mode.
 * </ul>
 * </ul>
 */
public class tSuite {
	public static final String testDisk = System.getProperty("user.dir");
	public static final String tmp = System.getProperty("java.io.tmpdir");

	static {
		System.out.println("path.separator="+System.getProperty("path.separator"));
		System.out.println("file.separator="+System.getProperty("file.separator"));
		System.out.println("user.dir="+testDisk);
		System.out.println("tmp.dir="+tmp);
	}

	public static void main(String[] args) throws InterruptedException/* throws IOException, InterruptedException*/, IOException {
		System.out.println("**************************");
		System.out.println("* in File System tSuite *");
		System.out.println("**************************");

		/* init test suite */
		File dir = new File(tSuite.testDisk);
		dir.mkdir();

		TestPathAndDir.main(null);
		TestFileAccess.main(args);
		TestFileProperties.main(null);
		TestListAndCompare.main(null);
		TestMultipleStreamOnSameFile.main(null);
		TestMultipleThreadOnSameFile.main(null);
		TestMultipleThreadOnMultipleFile.main(null);

		System.out.println("");
		System.out.println("______________");

	}

}
